MSG_HASH(
      MSG_COMPILER,
      "컴파일러"
      )
MSG_HASH(
      MSG_UNKNOWN_COMPILER,
      "알 수 없는 컴파일러"
      )
MSG_HASH(
      MSG_DEVICE_DISCONNECTED_FROM_PORT,
      "장치가 포트에서 연결 해제 되었습니다"
      )
MSG_HASH(
      MSG_UNKNOWN_NETPLAY_COMMAND_RECEIVED,
      "알 수 없는 넷플레이 명령어를 받았습니다"
      )
MSG_HASH(
      MSG_FILE_ALREADY_EXISTS_SAVING_TO_BACKUP_BUFFER,
      "파일이 이미 존재합니다. 백업 버퍼에 저장합니다"
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM,
      "다음에서 연결: \"%s\""
      )
MSG_HASH(
      MSG_GOT_CONNECTION_FROM_NAME,
      "다음에서 연결: \"%s (%s)\""
      )
MSG_HASH(
      MSG_PUBLIC_ADDRESS,
      "공개 주소"
      )
MSG_HASH(
      MSG_NO_ARGUMENTS_SUPPLIED_AND_NO_MENU_BUILTIN,
      "제공되는 인수 및 메뉴, 도움말이 없습니다..."
      )
MSG_HASH(
      MSG_SETTING_DISK_IN_TRAY,
      "디스크 트레이 설정"
      )
MSG_HASH(
      MSG_WAITING_FOR_CLIENT,
      "클라이언트 대기..."
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_LEFT_THE_GAME,
      "게임을 나왔습니다"
      )
MSG_HASH(
      MSG_NETPLAY_YOU_HAVE_JOINED_AS_PLAYER_N,
      "Y%u 플레이어로 입장했습니다"
      )
MSG_HASH(
      MSG_NETPLAY_ENDIAN_DEPENDENT,
      "현재 코어는 해당 시스템 사이에서 구조 간 넷플레이를 지원하지 않습니다"
      )
MSG_HASH(
      MSG_NETPLAY_PLATFORM_DEPENDENT,
      "현재 코어는 구조 간 넷플레이를 지원하지 않습니다"
      )
MSG_HASH(
      MSG_NETPLAY_ENTER_PASSWORD,
      "넷플레이 서버 비밀번호 입력:"
      )
MSG_HASH(
      MSG_NETPLAY_INCORRECT_PASSWORD,
      "잘못된 비밀번호"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_NAMED_HANGUP,
      "\"%s\" 접속 끊김"
      )
MSG_HASH(
      MSG_NETPLAY_SERVER_HANGUP,
      "넷플레이 클라이언트가 연결해제 되었습니다"
      )
MSG_HASH(
      MSG_NETPLAY_CLIENT_HANGUP,
      "넷플레이 연결해제"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_UNPRIVILEGED,
      "플레이 권한이 없습니다"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY_NO_SLOTS,
      "여유 플레이어 슬롯이 없습니다"
      )
MSG_HASH(
      MSG_NETPLAY_CANNOT_PLAY,
      "플레이 모드로 전환하지 못했습니다"
      )
MSG_HASH(
      MSG_NETPLAY_PEER_PAUSED,
      "넷플레이 피어 \"%s\" 일시정지됨"
      )
MSG_HASH(
      MSG_NETPLAY_CHANGED_NICK,
      "닉네임이 다음으로 변경됨: \"%s\""
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHARED_CONTEXT,
      "하드웨어 렌더링된 코어에 고유의 컨텍스트를 부여. 프레임간 하드웨어 상태가 변경된 것으로 가정하지 않도록 함."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_SETTINGS,
      "화면 표시 설정을 조정합니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC,
      "CPU와 GPU를 강제 동기화. 성능을 희생해 지연시간을 줄입니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_THREADED,
      "지연시간과 끊김을 감수하면서 성능을 향상. 풀 스피드를 얻지 못하는 경우에만 사용하십시오."
      )
MSG_HASH(
      MSG_AUDIO_VOLUME,
      "오디오 볼륨"
      )
MSG_HASH(
      MSG_AUTODETECT,
      "자동감지"
      )
MSG_HASH(
      MSG_AUTOLOADING_SAVESTATE_FROM,
      "저장상태 자동 불러오기: "
      )
MSG_HASH(
      MSG_CAPABILITIES,
      "기능"
      )
MSG_HASH(
      MSG_CONNECTING_TO_NETPLAY_HOST,
      "넷플레이 호스트에 접속 중"
      )
MSG_HASH(
      MSG_CONNECTING_TO_PORT,
      "포트에 접속중"
      )
MSG_HASH(
      MSG_CONNECTION_SLOT,
      "연결 슬롯"
      )
MSG_HASH(
      MSG_SORRY_UNIMPLEMENTED_CORES_DONT_DEMAND_CONTENT_NETPLAY,
      "죄송합니다, 구현실패: 컨텐츠를 요구하지 않는 코어는 넷플레이에 참여할 수 없습니다."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_PASSWORD,
      "비밀번호"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_SETTINGS,
      "계정 도전과제"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_CHEEVOS_USERNAME,
      "사용자 이름"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST,
      "계정"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_LIST_END,
      "계정 목록 종점"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "레트로 도전과제"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST,
      "도전과제 목록"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ACHIEVEMENT_LIST_HARDCORE,
      "도전과제 목록 (하드코어)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_CONTENT_LIST,
      "컨텐츠 검색"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS_LIST,
      "구성"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ADD_TAB,
      "컨텐츠 가져오기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_NETPLAY_TAB,
      "넷플레이"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASK_ARCHIVE,
      "묻기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_ASSETS_DIRECTORY,
      "애셋"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_BLOCK_FRAMES,
      "블록 프레임"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DEVICE,
      "오디오 장치"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DRIVER,
      "오디오 드라이버"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_DSP_PLUGIN,
      "오디오 DSP 플러그인"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE,
      "오디오 사용"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_FILTER_DIR,
      "오디오 필터"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_TURBO_DEADZONE_LIST,
      "터보/데드존"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_LATENCY,
      "오디오 지연 (ms)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MAX_TIMING_SKEW,
      "오디오 최대 타이밍 왜곡"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MUTE,
      "오디오 음소거"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_OUTPUT_RATE,
      "오디오 출력 레이트 (Hz)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RATE_CONTROL_DELTA,
      "다이나믹 오디오 레이트 제어"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_DRIVER,
      "오디오 리셈플러 드라이버"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SETTINGS,
      "오디오"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_SYNC,
      "오디오 싱크"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_VOLUME,
      "오디오 볼륨 레벨 (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTOSAVE_INTERVAL,
      "SaveRAM 자동저장 간격"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_OVERRIDES_ENABLE,
      "우선 설정 파일 자동으로 불러오기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_REMAPS_ENABLE,
      "입력 설정 파일 자동으로 불러오기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUTO_SHADERS_ENABLE,
      "쉐이드 프리셋 자동으로 불러오기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_BACK,
      "뒤로"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_CONFIRM,
      "확인"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_INFO,
      "정보"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_QUIT,
      "나가기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_DOWN,
      "아래로 스크롤"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_SCROLL_UP,
      "위로 스크롤"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_START,
      "시작"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_KEYBOARD,
      "키보드 전환"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_CONTROLS_TOGGLE_MENU,
      "메뉴 전환"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS,
      "기본 메뉴 조작"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_CONFIRM,
      "확인"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_INFO,
      "정보"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_QUIT,
      "나가기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_SCROLL_UP,
      "위로 스크롤"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_START,
      "기본"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_KEYBOARD,
      "키보드 전환"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BASIC_MENU_ENUM_CONTROLS_TOGGLE_MENU,
      "메뉴 전환"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLOCK_SRAM_OVERWRITE,
      "저장상태 불러올때 SaveRAM 덮어쓰지 않기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BLUETOOTH_ENABLE,
      "블루투스 사용"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BUILDBOT_ASSETS_URL,
      "빌드봇 애셋 URL"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CACHE_DIRECTORY,
      "캐시"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_ALLOW,
      "카메라 허용"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CAMERA_DRIVER,
      "카메라 드라이버"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT,
      "치트"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_APPLY_CHANGES,
      "변경 적용"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_DATABASE_PATH,
      "치트 파일"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE,
      "치트 파일"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_LOAD,
      "치트 파일 불러오기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_FILE_SAVE_AS,
      "치트 파일 다른 이름으로 저장"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEAT_NUM_PASSES,
      "치트 패스"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_DESCRIPTION,
      "설명"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_HARDCORE_MODE_ENABLE,
      "도전과제 하드코어 모드"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ACHIEVEMENTS,
      "해제한 도전과제:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_LOCKED_ENTRY,
      "잠김"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_SETTINGS,
      "레트로 도전과제"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_TEST_UNOFFICIAL,
      "비공식 도전과제 테스트"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ACHIEVEMENTS,
      "해제한 도전과제:"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CHEEVOS_UNLOCKED_ENTRY,
      "해제됨"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CLOSE_CONTENT,
      "컨텐츠 종료"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG,
      "환경설정"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATIONS,
      "환경설정 불러오기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIGURATION_SETTINGS,
      "환경설정"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONFIG_SAVE_ON_EXIT,
      "종료시 환경설정 저장하기"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_COLLECTION_LIST,
      "컬렉션"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DATABASE_DIRECTORY,
      "데이터베이스"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_DIR,
      "컨텐츠"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_SIZE,
      "실행 기록 목록 크기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_REMOVE,
      "항목 삭제 허용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SETTINGS,
      "빠른 메뉴")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIR,
      "다운로드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ASSETS_DIRECTORY,
      "다운로드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_CHEAT_OPTIONS,
      "치트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_COUNTERS,
      "코어 카운터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_ENABLE,
      "코어 이름 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFORMATION,
      "코어 정보")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_AUTHORS,
      "저자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CATEGORIES,
      "카테고리")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_LABEL,
      "코어 라벨")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_CORE_NAME,
      "코어 이름")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_FIRMWARE,
      "펌웨어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_LICENSES,
      "라이센스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_PERMISSIONS,
      "권한")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SUPPORTED_EXTENSIONS,
      "지원 확장자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_MANUFACTURER,
      "시스템 제조사")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INFO_SYSTEM_NAME,
      "시스템 이름")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_INPUT_REMAPPING_OPTIONS,
      "컨트롤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_LIST,
      "코어 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_OPTIONS,
      "옵션")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SETTINGS,
      "코어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_SET_SUPPORTS_NO_CONTENT_ENABLE,
      "자동으로 코어 시작")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "다운받은 압축파일 자동으로 압축해제")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_BUILDBOT_URL,
      "빌드봇 코어 URL")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_LIST,
      "코어 업데이터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_UPDATER_SETTINGS,
      "업데이터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_ARCHITECTURE,
      "CPU 아키텍쳐:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CPU_CORES,
      "CPU 코어:")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_DIRECTORY,
      "커서")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CURSOR_MANAGER,
      "커서 매니저")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CUSTOM_RATIO,
      "사용자 비율")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_MANAGER,
      "데이터베이스 매니저")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_SELECTION,
      "데이터베이스 선택")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DELETE_ENTRY,
      "제거")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FAVORITES,
      "시작 디렉토리")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_CONTENT,
      "<컨텐츠 경로>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_DEFAULT,
      "<기본>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NONE,
      "<없음>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_NOT_FOUND,
      "디렉토리 찾지 못함.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DIRECTORY_SETTINGS,
      "디렉토리")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_CYCLE_TRAY_STATUS,
      "디스크 사이클 트레이 상태")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_IMAGE_APPEND,
      "디스크 이미지 추가")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_INDEX,
      "디스크 인덱스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DISK_OPTIONS,
      "디스크 제어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DONT_CARE,
      "상관 없음")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOADED_FILE_DETECT_CORE_LIST,
      "다운로드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE,
      "코어 다운로드...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DOWNLOAD_CORE_CONTENT,
      "컨텐츠 다운로더")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_ENABLE,
      "DPI 오버라이드 허용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DPI_OVERRIDE_VALUE,
      "DPI 오버라이드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DRIVER_SETTINGS,
      "드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DUMMY_ON_CORE_SHUTDOWN,
      "코어 종료시 더미 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHECK_FOR_MISSING_FIRMWARE,
      "불러오기 전 부족한 펌웨어 체크")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPER,
      "다이나믹 백그라운드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DYNAMIC_WALLPAPERS_DIRECTORY,
      "다이나믹 백그라운드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CHEEVOS_ENABLE,
      "도전과제 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_HOVER_COLOR,
      "메뉴 항목 하이라이트 색상")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ENTRY_NORMAL_COLOR,
      "메뉴 항목 일반 색상")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FALSE,
      "False")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FASTFORWARD_RATIO,
      "최대 실행 속도")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FPS_SHOW,
      "FPS 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_ENABLE,
      "최대 실행 속도 제한")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRAME_THROTTLE_SETTINGS,
      "프레임 조절")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FRONTEND_COUNTERS,
      "프론트엔드 카운터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS,
      "컨텐츠 특정 코어 옵션 자동으로 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_CREATE,
      "게임 옵션 파일 생성")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GAME_SPECIFIC_OPTIONS_IN_USE,
      "게임 옵션 파일")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP,
      "도움말")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_AUDIO_VIDEO_TROUBLESHOOTING,
      "오디오/비디오 문제해결")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CHANGE_VIRTUAL_GAMEPAD,
      "가상 게임패드 오버레이 변경")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_CONTROLS,
      "기본 메뉴 컨트롤")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LIST,
      "도움말")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_LOADING_CONTENT,
      "컨텐츠 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_SCANNING_CONTENT,
      "컨텐츠 검색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HELP_WHAT_IS_A_CORE,
      "코어는 무엇인가?")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_LIST_ENABLE,
      "최근 실행목록 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HISTORY_TAB,
      "최근 실행")
MSG_HASH(MENU_ENUM_LABEL_VALUE_HORIZONTAL_MENU,
      "수평 메뉴")
MSG_HASH(MENU_ENUM_LABEL_VALUE_IMAGES_TAB,
      "이미지")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION,
      "정보")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INFORMATION_LIST,
      "정보")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ADC_TYPE,
      "아날로그 디지털 패드 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ALL_USERS_CONTROL_MENU,
      "전체 사용자 컨트롤 메뉴")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X,
      "좌 아날로그 X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_MINUS,
      "좌 아날로그 X- (좌)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_X_PLUS,
      "좌 아날로그 X+ (우)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y,
      "좌 아날로그 Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_MINUS,
      "좌 아날로그 Y- (up)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_LEFT_Y_PLUS,
      "좌 아날로그 Y+ (down)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X,
      "우 아날로그 X")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_MINUS,
      "우 아날로그 X- (좌)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_X_PLUS,
      "우 아날로그 X+ (우)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y,
      "우 아날로그 Y")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_MINUS,
      "우 아날로그 Y- (상)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ANALOG_RIGHT_Y_PLUS,
      "우 아날로그 Y+ (하)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_TRIGGER,
      "Gun Trigger")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_RELOAD,
      "Gun Reload")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_A,
      "Gun Aux A")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_B,
      "Gun Aux B")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_AUX_C,
      "Gun Aux C")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_START,
      "Gun Start")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_SELECT,
      "Gun Select")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_UP,
      "Gun D-pad Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_DOWN,
      "Gun D-pad Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_LEFT,
      "Gun D-pad Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_LIGHTGUN_DPAD_RIGHT,
      "Gun D-pad Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AUTODETECT_ENABLE,
      "자동설정 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_AXIS_THRESHOLD,
      "아날로그 스틱 데드존")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_INPUT_SWAP_OK_CANCEL,
      "확인/취소 버튼 반전")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_ALL,
      "모두 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_DEFAULT_ALL,
      "모두 기본 값으로 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_BIND_TIMEOUT,
      "설정 시간 만료")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_HIDE_UNBOUND,
      "설정 안된 코어 입력 기술자 숨김")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DESCRIPTOR_LABEL_SHOW,
      "입력 기술자 라벨 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_INDEX,
      "장치 인덱스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DEVICE_TYPE,
      "장치 종류")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DRIVER,
      "입력 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_DUTY_CYCLE,
      "듀티 사이클")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_HOTKEY_BINDS,
      "입력 핫키 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_ICADE_ENABLE,
      "키보드 방식 게임패트 설정 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_A,
      "A 버튼 (우)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_B,
      "B 버튼 (하)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_DOWN,
      "아래 D-패드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L2,
      "L2 버튼 (트리거)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L3,
      "L3 버튼 (엄지)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_L,
      "L 버튼 (숄더)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_LEFT,
      "왼쪽 D-패드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R2,
      "R2 버튼 (트리거)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R3,
      "R3 버튼 (엄지)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_R,
      "R 버튼 (숄더)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_RIGHT,
      "오른쪽 D-패드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_SELECT,
      "셀렉트 버튼")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_START,
      "스타트 버튼")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_UP,
      "위 D-패드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_X,
      "X 버튼 (상)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_JOYPAD_Y,
      "Y 버튼 (좌)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEY,
      "(키: %s)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_LEFT,
      "Mouse 1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_RIGHT,
      "Mouse 2")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_MIDDLE,
      "Mouse 3")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON4,
      "Mouse 4")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_BUTTON5,
      "Mouse 5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_UP,
      "Wheel Up")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_WHEEL_DOWN,
      "Wheel Down")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_UP,
      "Wheel Left")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MOUSE_HORIZ_WHEEL_DOWN,
      "Wheel Right")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_KEYBOARD_GAMEPAD_MAPPING_TYPE,
      "키보드 게임패드 설정 형식")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MAX_USERS,
      "최대 사용자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "메뉴 호출 게임패드 조합")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_MINUS,
      "치트 인덱스 -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_INDEX_PLUS,
      "치트 인덱스 +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_CHEAT_TOGGLE,
      "치트 켜기/끄기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_EJECT_TOGGLE,
      "디스크 꺼내기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_NEXT,
      "다음 디스크")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_DISK_PREV,
      "이전 디스크")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_ENABLE_HOTKEY,
      "핫키 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_HOLD_KEY,
      "빨리 진행하기 홀드버튼")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FAST_FORWARD_KEY,
      "빨리 진행하기 켜기/끄기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FRAMEADVANCE,
      "다음 프레임")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_FULLSCREEN_TOGGLE_KEY,
      "전체화면 켜기/끄기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GRAB_MOUSE_TOGGLE,
      "마우스 켜기/끄기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_GAME_FOCUS_TOGGLE,
      "게임 포커스 사용/해제")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_LOAD_STATE_KEY,
      "상태 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MENU_TOGGLE,
      "메뉴 열기/닫기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MOVIE_RECORD_TOGGLE,
      "동영상 기록 시작/중지")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_MUTE,
      "음소거 켜기/끄기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_NETPLAY_GAME_WATCH,
      "넷플레이 플레이/관전 전환")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OSK,
      "화상 키보드 켜기/끄기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_OVERLAY_NEXT,
      "다음 오버레이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_PAUSE_TOGGLE,
      "일시정지 켜기/끄기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_QUIT_KEY,
      "RetroArch 종료")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_RESET,
      "게임 초기화")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_REWIND,
      "뒤로감기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SAVE_STATE_KEY,
      "상태 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SCREENSHOT,
      "스크린샷 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_NEXT,
      "다음 쉐이더")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SHADER_PREV,
      "이전 쉐이더")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_SLOWMOTION_HOLD_KEY,
      "슬로우 모션")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_MINUS,
      "상태저장 슬롯 -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_STATE_SLOT_PLUS,
      "상태저장 슬롯 +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_DOWN,
      "볼륨 -")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_META_VOLUME_UP,
      "볼륨 +")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_ENABLE,
      "오버레이 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_OVERLAY_HIDE_IN_MENU,
      "메뉴에서 오버레이 숨김")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR,
      "폴 타입 동작")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_EARLY,
      "일찍")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_LATE,
      "늦게")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_POLL_TYPE_BEHAVIOR_NORMAL,
      "보통")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_PREFER_FRONT_TOUCH,
      "Prefer Front Touch")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAPPING_DIRECTORY,
      "입력설정 파일")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_REMAP_BINDS_ENABLE,
      "입력설정 파일 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SAVE_AUTOCONFIG,
      "자동설정 저정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SETTINGS,
      "입력")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_SMALL_KEYBOARD_ENABLE,
      "작은 키보드 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TOUCH_ENABLE,
      "터치 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_ENABLE,
      "터보 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_TURBO_PERIOD,
      "터보 간격")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_USER_BINDS,
      "사용자 %u 입력 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INTERNAL_STORAGE_STATUS,
      "내부 저장공간 상태")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_AUTOCONFIG_DIR,
      "입력 자동설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_JOYPAD_DRIVER,
      "조이패드 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LAKKA_SERVICES,
      "서비스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_SIMPLIFIED,
      "중국어 (간체)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_CHINESE_TRADITIONAL,
      "중국어 (번체)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_DUTCH,
      "네덜란드어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ENGLISH,
      "영어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ESPERANTO,
      "에스페란토")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_FRENCH,
      "프랑스어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_GERMAN,
      "독일어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ITALIAN,
      "이탈리아어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_JAPANESE,
      "일본어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_KOREAN,
      "한국어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_POLISH,
      "폴란드어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_BRAZIL,
      "포르투칼어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_PORTUGUESE_PORTUGAL,
      "포르투칼어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_RUSSIAN,
      "러시아어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_SPANISH,
      "스페인어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_VIETNAMESE,
      "베트남어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LANG_ARABIC,
      "Arabic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LEFT_ANALOG,
      "좌 아날로그")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_DIR_PATH,
      "코어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_INFO_PATH,
      "코어 정보")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LIBRETRO_LOG_LEVEL,
      "코어 로그 레벨")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LINEAR,
      "선형")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_ARCHIVE,
      "압축파일 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_HISTORY,
      "최근 컨텐츠 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_CONTENT_LIST,
      "컨텐츠 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOAD_STATE,
      "상태저장 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_ALLOW,
      "위치 허용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOCATION_DRIVER,
      "위치 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOGGING_SETTINGS,
      "로그")
MSG_HASH(MENU_ENUM_LABEL_VALUE_LOG_VERBOSITY,
      "로그 내용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MAIN_MENU,
      "메인 메뉴")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MANAGEMENT,
      "데이터베이스 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME,
      "메뉴 테마 색상")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE,
      "파란색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_BLUE_GREY,
      "청회색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_DARK_BLUE,
      "짙은 파란색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_GREEN,
      "녹색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_NVIDIA_SHIELD,
      "실드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_RED,
      "빨간색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_COLOR_THEME_YELLOW,
      "노란색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_FOOTER_OPACITY,
      "푸터 투명도")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_MENU_HEADER_OPACITY,
      "헤더 투명도")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DRIVER,
      "메뉴 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENUM_THROTTLE_FRAMERATE,
      "메뉴 프레임레이트 제한")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FILE_BROWSER_SETTINGS,
      "설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_LINEAR_FILTER,
      "메뉴 선형 필터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SETTINGS,
      "메뉴")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER,
      "배경")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_WALLPAPER_OPACITY,
      "배경 투명도")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MISSING,
      "누락")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MORE,
      "...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MOUSE_ENABLE,
      "마우스 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MULTIMEDIA_SETTINGS,
      "멀티미디어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MUSIC_TAB,
      "음악")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "알 수 없는 확장자 숨김")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NAVIGATION_WRAPAROUND,
      "이동 경로 연결")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NEAREST,
      "근접")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY,
      "넷플레이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ALLOW_SLAVES,
      "슬레이브 모드 클라이언트 허용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_CHECK_FRAMES,
      "넷플레이 프레임 체크")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "입력 대기 프레임")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "입력 대기 프레임 범위")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DELAY_FRAMES,
      "넷플레이 지연 프레임")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISCONNECT,
      "넷플레이 호스트로부터 연결해제")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE,
      "넷플레이 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_CLIENT,
      "넷플레이 호스트 연결")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ENABLE_HOST,
      "넷플레이 호스트 시작")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_DISABLE_HOST,
      "Stop netplay host")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_IP_ADDRESS,
      "서버 주소")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LAN_SCAN_SETTINGS,
      "내부 네트워크 검색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_MODE,
      "넷플레이 클라이언트 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NICKNAME,
      "사용자 이름")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PASSWORD,
      "서버 비밀번호")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_PUBLIC_ANNOUNCE,
      "공개 넷플레이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REQUIRE_SLAVES,
      "비 슬레이브 모드 클라이언트 차단")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SETTINGS,
      "넷플레이 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_AS_SPECTATOR,
      "넷플레이 관전 모드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_STATELESS_MODE,
      "넷플레이 상태저장금지 모드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATE_PASSWORD,
      "서버 관전 전용 비밀번호")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_SPECTATOR_MODE_ENABLE,
      "넷플레이 관전 허용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_TCP_UDP_PORT,
      "넷플레이 TCP 포트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_NAT_TRAVERSAL,
      "넷플레이 NAT 상태")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_ENABLE,
      "네트워크 명령")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_CMD_PORT,
      "네트워크 명령 포트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_INFORMATION,
      "네트워크 정보")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_ENABLE,
      "네트워크 게임패드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_REMOTE_PORT,
      "네트워크 원격 기본 포트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_SETTINGS,
      "네트워크")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO,
      "아니오")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NONE,
      "없음")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NOT_AVAILABLE,
      "이용불가")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ACHIEVEMENTS_TO_DISPLAY,
      "표시할 도전과제 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE,
      "코어 없음")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORES_AVAILABLE,
      "이용 가능한 코어 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_INFORMATION_AVAILABLE,
      "이용 가능한 코어 정보 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_CORE_OPTIONS_AVAILABLE,
      "이용 가능한 코어 옵션 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ENTRIES_TO_DISPLAY,
      "표시할 항목 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_HISTORY_AVAILABLE,
      "이용 가능한 게임 기록자료 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_INFORMATION_AVAILABLE,
      "이용 가능한 정보 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_ITEMS,
      "항목 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETPLAY_HOSTS_FOUND,
      "넷플레이 호스트 찾지 못함.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_NETWORKS_FOUND,
      "네트워크 찾지 못함.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PERFORMANCE_COUNTERS,
      "성능 카운터 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLISTS,
      "실행목록 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_PLAYLIST_ENTRIES_AVAILABLE,
      "이용 가능한 항목 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SETTINGS_FOUND,
      "설정 항목 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NO_SHADER_PARAMETERS,
      "쉐이더 매개변수 없음.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OFF,
      "끔")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ON,
      "켬")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE,
      "온라인")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONLINE_UPDATER,
      "온라인 업데이터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_DISPLAY_SETTINGS,
      "OSD 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_OVERLAY_SETTINGS,
      "OSD 오버레이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ONSCREEN_NOTIFICATIONS_SETTINGS,
      "OSD 알림")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPEN_ARCHIVE,
      "압축파일 탐색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OPTIONAL,
      "옵션")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY,
      "오버레이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_AUTOLOAD_PREFERRED,
      "선호 오버레이 자동 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_DIRECTORY,
      "오버레이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_OPACITY,
      "오버레이 투명도")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_PRESET,
      "오버레이 프리셋")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SCALE,
      "오버레이 크기조절")
MSG_HASH(MENU_ENUM_LABEL_VALUE_OVERLAY_SETTINGS,
      "OSD 오버레이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAL60_ENABLE,
      "PAL60모드 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PARENT_DIRECTORY,
      "상위 폴더")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_LIBRETRO,
      "메뉴 실행 시 일시정지")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PAUSE_NONACTIVE,
      "배경에서 실행하지 않음")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PERFCNT_ENABLE,
      "성능 카운터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLISTS_TAB,
      "실행목록")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_DIRECTORY,
      "실행목록")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_SETTINGS,
      "실행목록")
MSG_HASH(MENU_ENUM_LABEL_VALUE_POINTER_ENABLE,
      "터치 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PORT,
      "포트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRESENT,
      "사용중")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PRIVACY_SETTINGS,
      "개인정보 보호")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUIT_RETROARCH,
      "RetroArch 종료")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ANALOG,
      "아날로그 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_BBFC_RATING,
      "BBFC 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CERO_RATING,
      "CERO 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_COOP,
      "협동모드 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_CRC32,
      "CRC32")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DESCRIPTION,
      "설명")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_DEVELOPER,
      "개발사")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_ISSUE,
      "에지 매거진 기사")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_RATING,
      "에지 매거진 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_EDGE_MAGAZINE_REVIEW,
      "에지 매거진 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ELSPA_RATING,
      "ELSPA 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ENHANCEMENT_HW,
      "개선 하드웨어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ESRB_RATING,
      "ESRB 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FAMITSU_MAGAZINE_RATING,
      "패미통 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_FRANCHISE,
      "프랜차이즈")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_GENRE,
      "장르")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_MD5,
      "MD5")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_NAME,
      "이름")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_ORIGIN,
      "Origin")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PEGI_RATING,
      "PEGI 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_PUBLISHER,
      "판매사")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_MONTH,
      "출시 월")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RELEASE_YEAR,
      "출시 년")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_RUMBLE,
      "진동 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SERIAL,
      "시리얼")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_SHA1,
      "SHA1")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_START_CONTENT,
      "컨텐츠 시작")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RDB_ENTRY_TGDB_RATING,
      "TGDB 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REBOOT,
      "재시작")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_CONFIG_DIRECTORY,
      "녹화 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_OUTPUT_DIRECTORY,
      "녹화 출력")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORDING_SETTINGS,
      "녹화")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_CONFIG,
      "녹화 설정 불러오기...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_DRIVER,
      "녹화 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_ENABLE,
      "녹화 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_PATH,
      "녹화 출력을 다음으로 저장...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RECORD_USE_OUTPUT_DIRECTORY,
      "녹화를 출력 폴더에 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE,
      "입력설정 파일")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_LOAD,
      "입력설정 파일 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_CORE,
      "코어 입력설정 파일 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REMAP_FILE_SAVE_GAME,
      "게임 입력설정 파일 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REQUIRED,
      "필요")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_CONTENT,
      "다시 시작")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESTART_RETROARCH,
      "RetroArch 다시 시작")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME,
      "이어하기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RESUME_CONTENT,
      "이어하기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROKEYBOARD,
      "Retro키보드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD,
      "Retro패드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETROPAD_WITH_ANALOG,
      "Retro패드 아날로그")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RETRO_ACHIEVEMENTS_SETTINGS,
      "도전과제")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_ENABLE,
      "뒤로감기 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_GRANULARITY,
      "뒤로감기 세부제어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_REWIND_SETTINGS,
      "뒤로감기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_BROWSER_DIRECTORY,
      "파일 탐색기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_CONFIG_DIRECTORY,
      "설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RGUI_SHOW_START_SCREEN,
      "시작 화면 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RIGHT_ANALOG,
      "우 아날로그")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RUN,
      "실행")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAMBA_ENABLE,
      "SAMBA 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVEFILE_DIRECTORY,
      "세이브파일")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_INDEX,
      "상태저장 자동 인덱스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_LOAD,
      "자동 상태 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_AUTO_SAVE,
      "자동 상태저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_DIRECTORY,
      "상태저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVESTATE_THUMBNAIL_ENABLE,
      "상태저장 미리보기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG,
      "현재 환경설정 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "코어 우선 설정 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "게임 우선 설정 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_NEW_CONFIG,
      "새 환경설정 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVE_STATE,
      "상태저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SAVING_SETTINGS,
      "저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_DIRECTORY,
      "디렉토리 검색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_FILE,
      "파일 검색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCAN_THIS_DIRECTORY,
      "<현재 디렉토리 검색>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREENSHOT_DIRECTORY,
      "스크린샷")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCREEN_RESOLUTION,
      "화면 해상도")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SEARCH,
      "검색")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SECONDS,
      "초")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS,
      "설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SETTINGS_TAB,
      "설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER,
      "쉐이더")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_APPLY_CHANGES,
      "변경 적용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_OPTIONS,
      "쉐이더")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON,
      "리본")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_RIBBON_SIMPLIFIED,
      "리본 (단순화)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SIMPLE_SNOW,
      "Simple Snow")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_SNOW,
      "Snow")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_ADVANCED_SETTINGS,
      "고급 설정 보임")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHOW_HIDDEN_FILES,
      "숨겨진 파일 및 폴더 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHUTDOWN,
      "종료")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SLOWMOTION_RATIO,
      "슬로우 모션 비율")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVEFILES_ENABLE,
      "폴더 안 세이브파일 정렬")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SORT_SAVESTATES_ENABLE,
      "폴더 안 상태저장파일 정렬")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SSH_ENABLE,
      "SSH 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_CORE,
      "코어 실행")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_NET_RETROPAD,
      "원격 레트로패드 실행")
MSG_HASH(MENU_ENUM_LABEL_VALUE_START_VIDEO_PROCESSOR,
      "비디오 프로세서 실행")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATE_SLOT,
      "저장 슬롯")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATUS,
      "상태")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STDIN_CMD_ENABLE,
      "stdin 명령")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUPPORTED_CORES,
      "추천 코어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SUSPEND_SCREENSAVER_ENABLE,
      "화면보호기 동작 차단")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_BGM_ENABLE,
      "시스템 BGM 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_DIRECTORY,
      "시스템/바이오스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFORMATION,
      "시스템 정보")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_7ZIP_SUPPORT,
      "7zip 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ALSA_SUPPORT,
      "ALSA 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_BUILD_DATE,
      "빌드 일시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CG_SUPPORT,
      "Cg 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COCOA_SUPPORT,
      "Cocoa 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_COMMAND_IFACE_SUPPORT,
      "명령줄 인터페이스 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CORETEXT_SUPPORT,
      "CoreText 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_CPU_FEATURES,
      "CPU 기능")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_DPI,
      "화면 DPI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_HEIGHT,
      "화면 높이(mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DISPLAY_METRIC_MM_WIDTH,
      "화면 너비(mm)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DSOUND_SUPPORT,
      "DirectSound 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WASAPI_SUPPORT,
      "WASAPI 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYLIB_SUPPORT,
      "다이나믹 라이브러리 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_DYNAMIC_SUPPORT,
      "libretro 라이브러리 다이나믹 런타임 로딩")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_EGL_SUPPORT,
      "EGL 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FBO_SUPPORT,
      "OpenGL/Direct3D 텍스쳐 랜더링(멀티패스 쉐이더) 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FFMPEG_SUPPORT,
      "FFmpeg 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FREETYPE_SUPPORT,
      "FreeType 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_IDENTIFIER,
      "프론트엔드 식별자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_NAME,
      "프론트엔드 이름")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_FRONTEND_OS,
      "프론트엔드 OS")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GIT_VERSION,
      "Git 버전")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_GLSL_SUPPORT,
      "GLSL 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_HLSL_SUPPORT,
      "HLSL 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_JACK_SUPPORT,
      "JACK 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_KMS_SUPPORT,
      "KMS/EGL 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBRETRODB_SUPPORT,
      "LibretroDB 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBUSB_SUPPORT,
      "Libusb 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_LIBXML2_SUPPORT,
      "libxml2 XML 파싱 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETPLAY_SUPPORT,
      "넷플레이 (P2P) 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_COMMAND_IFACE_SUPPORT,
      "네트워크 명령줄 인터페이스 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_NETWORK_REMOTE_SUPPORT,
      "네트워크 게임패드 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENAL_SUPPORT,
      "OpenAL 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGLES_SUPPORT,
      "OpenGL ES 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENGL_SUPPORT,
      "OpenGL 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENSL_SUPPORT,
      "OpenSL 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OPENVG_SUPPORT,
      "OpenVG 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OSS_SUPPORT,
      "OSS 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_OVERLAY_SUPPORT,
      "오버레이 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE,
      "전원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGED,
      "충전됨")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_CHARGING,
      "충전중")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_DISCHARGING,
      "방전중")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_POWER_SOURCE_NO_SOURCE,
      "없음")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PULSEAUDIO_SUPPORT,
      "PulseAudio 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_PYTHON_SUPPORT,
      "Python (쉐이더에서 지원) 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RBMP_SUPPORT,
      "BMP 지원 (RBMP)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RETRORATING_LEVEL,
      "RetroRating 수준")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RJPEG_SUPPORT,
      "JPEG 지원 (RJPEG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ROARAUDIO_SUPPORT,
      "RoarAudio 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RPNG_SUPPORT,
      "PNG 지원 (RPNG)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RSOUND_SUPPORT,
      "RSound 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_RTGA_SUPPORT,
      "TGA 지원 (RTGA)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL2_SUPPORT,
      "SDL2 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_IMAGE_SUPPORT,
      "SDL 이미지 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SDL_SUPPORT,
      "SDL1.2 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_SLANG_SUPPORT,
      "Slang 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_THREADING_SUPPORT,
      "스레딩 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_UDEV_SUPPORT,
      "Udev 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_V4L2_SUPPORT,
      "Video4Linux2 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VIDEO_CONTEXT_DRIVER,
      "비디오 컨텍스트 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_VULKAN_SUPPORT,
      "Vulkan 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_WAYLAND_SUPPORT,
      "Wayland 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_X11_SUPPORT,
      "X11 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XAUDIO2_SUPPORT,
      "XAudio2 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_XVIDEO_SUPPORT,
      "XVideo 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SYSTEM_INFO_ZLIB_SUPPORT,
      "Zlib 지원")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TAKE_SCREENSHOT,
      "스크린샷 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THREADED_DATA_RUNLOOP_ENABLE,
      "다중 스레드 작업")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS,
      "미리보기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_DIRECTORY,
      "미리보기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAILS_UPDATER_LIST,
      "미리보기 업데이터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_BOXARTS,
      "박스아트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_SCREENSHOTS,
      "스크린샷")
MSG_HASH(MENU_ENUM_LABEL_VALUE_THUMBNAIL_MODE_TITLE_SCREENS,
      "타이틀 화면")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TIMEDATE_ENABLE,
      "시간/날짜 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TITLE_COLOR,
      "메뉴 타이틀 색상")
MSG_HASH(MENU_ENUM_LABEL_VALUE_TRUE,
      "True")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_ENABLE,
      "UI 컴패니언 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_COMPANION_START_ON_BOOT,
      "부팅시 UI 컴패니언 실행")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UI_MENUBAR_ENABLE,
      "메뉴바")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNABLE_TO_READ_COMPRESSED_FILE,
      "압축 파일을 읽을 수 없습니다.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_LOAD_STATE,
      "상태 불러오기 취소")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNDO_SAVE_STATE,
      "상태저장 되돌리기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UNKNOWN,
      "알 수 없음")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATER_SETTINGS,
      "업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_ASSETS,
      "애셋 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_AUTOCONFIG_PROFILES,
      "자동설정 프로필 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CG_SHADERS,
      "Cg 쉐이더 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CHEATS,
      "치트 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_CORE_INFO_FILES,
      "코어 정보 파일 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_DATABASES,
      "데이터베이스 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_GLSL_SHADERS,
      "GLSL 쉐이더 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_LAKKA,
      "Lakka 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_OVERLAYS,
      "오버레이 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_UPDATE_SLANG_SHADERS,
      "Slang 쉐이더 업데이트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER,
      "사용자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_INTERFACE_SETTINGS,
      "사용자 인터페이스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_LANGUAGE,
      "언어")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USER_SETTINGS,
      "사용자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_IMAGE_VIEWER,
      "내장 이미지 뷰어 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_BUILTIN_PLAYER,
      "내장 미디어 플레이어 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_USE_THIS_DIRECTORY,
      "<현재 디렉토리 사용>")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ALLOW_ROTATE,
      "회전 허용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_AUTO,
      "자동 화면비")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ASPECT_RATIO_INDEX,
      "화면비")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_BLACK_FRAME_INSERTION,
      "검은 프레임 삽입")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_CROP_OVERSCAN,
      "오버스캔 잘라내기(재시작)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DISABLE_COMPOSITION,
      "데스크탑 구성요소 사용안함")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_DRIVER,
      "비디오 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER,
      "비디오 필터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_DIR,
      "비디오 필터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FILTER_FLICKER,
      "깜빡임 필터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_ENABLE,
      "OSD 알림 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_PATH,
      "OSD 알림 폰트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FONT_SIZE,
      "OSD 알림 크기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_ASPECT,
      "강제 화면 비율")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FORCE_SRGB_DISABLE,
      "sRGB FBO 강제 사용해제")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FRAME_DELAY,
      "프레임 지연")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_FULLSCREEN,
      "전체화면 모드 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GAMMA,
      "비디오 감마")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_RECORD,
      "GPU 녹화 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_GPU_SCREENSHOT,
      "GPU 스크린샷 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC,
      "강제 GPU 동기화")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_HARD_SYNC_FRAMES,
      "강제 GPU 동기화 프레임")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "최대 스왑체인 이미지")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_X,
      "OSD 알림 X 위치")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MESSAGE_POS_Y,
      "OSD 알림 Y 위치")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_MONITOR_INDEX,
      "모니터 인덱스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_POST_FILTER_RECORD,
      "필터 적용된 녹화 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE,
      "수직 리프레시 비율")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_POLLED,
      "Set Display-Reported Refresh Rate")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_REFRESH_RATE_AUTO,
      "화면 프레임레이트 측정치")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_ROTATION,
      "화면회전")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE,
      "창모드 크기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SCALE_INTEGER,
      "정수 단위 화면 크기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SETTINGS,
      "비디오")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_DIR,
      "비디오 쉐이더")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_NUM_PASSES,
      "쉐이더 패스")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PARAMETERS,
      "쉐이더 매개변수 미리보기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET,
      "쉐이더 프리셋 불러오기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_AS,
      "쉐이더 프리셋 다른 이름으로 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_CORE,
      "코어 프리셋 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHADER_PRESET_SAVE_GAME,
      "게임 프리셋 저장")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SHARED_CONTEXT,
      "하드웨어 공유 콘텍스트 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SMOOTH,
      "이중선형 필터링")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SOFT_FILTER,
      "소프트 필터 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_SWAP_INTERVAL,
      "수직 동기화 (Vsync) 스왑 간격")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_TAB,
      "비디오")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_THREADED,
      "스레드된 비디오")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VFILTER,
      "디플릭커")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "사용자 화면비 높이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "사용자 화면비 폭")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_X,
      "사용자 화면비 X 위치.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VIEWPORT_CUSTOM_Y,
      "사용자 화면비 Y 위치.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VI_WIDTH,
      "VI 화면 폭 설정")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_VSYNC,
      "수직 동기화 (Vsync)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOWED_FULLSCREEN,
      "전체 창화면 모드")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_WIDTH,
      "윈도우 폭")
MSG_HASH(MENU_ENUM_LABEL_VALUE_VIDEO_WINDOW_HEIGHT,
      "윈도우 높이")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_DRIVER,
      "Wi-Fi 드라이버")
MSG_HASH(MENU_ENUM_LABEL_VALUE_WIFI_SETTINGS,
      "Wi-Fi")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ALPHA_FACTOR,
      "메뉴 알파 요소")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_RED,
      "Menu Font Red Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_GREEN,
      "Menu Font Green Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FONT_COLOR_BLUE,
      "Menu Font Blue Color")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_FONT,
      "메뉴 폰트")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_CUSTOM,
      "사용자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_FLATUI,
      "FlatUI")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME,
      "Monochrome")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_MONOCHROME_INVERTED,
      "Monochrome Inverted")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_SYSTEMATIC,
      "Systematic")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_NEOACTIVE,
      "NeoActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_PIXEL,
      "Pixel")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROACTIVE,
      "RetroActive")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_RETROSYSTEM,
      "Retrosystem")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_ICON_THEME_DOTART,
      "Dot-Art")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME,
      "메뉴 색상 테마")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_APPLE_GREEN,
      "Apple Green")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK,
      "Dark")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_DARK_PURPLE,
      "Dark Purple")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_ELECTRIC_BLUE,
      "Electric Blue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_GOLDEN,
      "Golden")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_LEGACY_RED,
      "Legacy Red")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_MIDNIGHT_BLUE,
      "Midnight Blue")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_PLAIN,
      "Plain")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_UNDERSEA,
      "Undersea")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MENU_COLOR_THEME_VOLCANIC_RED,
      "Volcanic Red")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_RIBBON_ENABLE,
      "메뉴 쉐이더 파이프라인")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SCALE_FACTOR,
      "메뉴 크기 요소")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_SHADOWS_ENABLE,
      "아이콘 그림자 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_HISTORY,
      "최근 목록 탭 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_ADD,
      "가져온 컨텐츠 탭 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_IMAGES,
      "이미지 탭 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_MUSIC,
      "음악 탭 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS,
      "설정 탭 보이기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_VIDEO,
      "비디오 탭 보이기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_NETPLAY,
      "넷플레이 탭 보이기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_LAYOUT,
      "Menu Layout")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_THEME,
      "메뉴 아이콘 테마")
MSG_HASH(MENU_ENUM_LABEL_VALUE_YES,
      "예")
MSG_HASH(MENU_ENUM_LABEL_VIDEO_SHADER_PRESET_TWO,
      "쉐이더 프리셋")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_ENABLE,
      "도전과제 사용 설정. 자세한 정보는 http://retroachievements.org 방문.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_TEST_UNOFFICIAL,
      "비공식 도전과제 또는 테스트 목적의 베타기능 사용 설정/해제.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_HARDCORE_MODE_ENABLE,
      "모든 게임에 대한 상태저장, 치트, 뒤로감기, 빨리감기, 일시정지, 슬로우모션 사용 설정/해제.")
MSG_HASH(MENU_ENUM_SUBLABEL_DRIVER_SETTINGS,
      "시스템에서 사용되는 드라이버를 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_RETRO_ACHIEVEMENTS_SETTINGS,
      "도전과제 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_SETTINGS,
      "코어설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_SETTINGS,
      "녹화 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONSCREEN_DISPLAY_SETTINGS,
      "화면 오버레이 및 화상키보드, OSD 알림 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_FRAME_THROTTLE_SETTINGS,
      "뒤로감기, 빨리감기, 슬로우모션 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVING_SETTINGS,
      "저장 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOGGING_SETTINGS,
      "로그파일 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_INTERFACE_SETTINGS,
      "사용자 인터페이스 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_SETTINGS,
      "계정, 사용자 이름, 언어설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_PRIVACY_SETTINGS,
      "개인정보 보호 설정 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_DIRECTORY_SETTINGS,
      "파일이 위치할 기본 디렉토리 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_SETTINGS,
      "실행목록 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_SETTINGS,
      "서버 및 네트워크 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_CONTENT_LIST,
      "컨텐츠 검색 및 데이터베이스 추가.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_SETTINGS,
      "오디오 출력 설정 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_BLUETOOTH_ENABLE,
      "블루투스 사용/해제.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIG_SAVE_ON_EXIT,
      "종료시 변경된 설정을 저장.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATION_SETTINGS,
      "환경설정 파일에 대한 기본 설정 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONFIGURATIONS_LIST,
      "환경설정 파일 생성 및 관리.")
MSG_HASH(MENU_ENUM_SUBLABEL_CPU_CORES,
      "CPU가 가진 코어 개수.")
MSG_HASH(MENU_ENUM_SUBLABEL_FPS_SHOW,
      "화면에 현재 FPS 표시.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_HOTKEY_BINDS,
      "핫키 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_MENU_ENUM_TOGGLE_GAMEPAD_COMBO,
      "메뉴 호출을 위한 게임패트 콤보입력.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_SETTINGS,
      "조이패드, 키보드, 마우스 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_USER_BINDS,
      "현재 사용자에 대한 입력 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOG_VERBOSITY,
      "터미널에 로그기록 사용/사용안함.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY,
      "넷플레이 세션을 개설하거나 참가.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_LAN_SCAN_SETTINGS,
      "내부 네트워크 상의 넷플레이 호스트를 검색.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION_LIST_LIST,
      "코어, 네트워크 및 시스템 정보 표시.")
MSG_HASH(MENU_ENUM_SUBLABEL_ONLINE_UPDATER,
      "RetroArch용 애드온, 구성요소 및 컨텐츠 다운로드.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAMBA_ENABLE,
      "네트워크 폴더 공유 사용/해제.")
MSG_HASH(MENU_ENUM_SUBLABEL_SERVICES_SETTINGS,
      "OS 수준 서비스 관리.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_HIDDEN_FILES,
      "파일 탐색기에 숨김 파일/폴더 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_SSH_ENABLE,
      "원격 명령줄 접근 사용/해제.")
MSG_HASH(MENU_ENUM_SUBLABEL_SUSPEND_SCREENSAVER_ENABLE,
      "시스템 화면보호기 동작 방지.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_SCALE,
      "코어 뷰포트 사이즈에 대해 상대적인 윈도우크기 설정. - 고정된 윈도우 크기를 위한 높이 및 폭 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_USER_LANGUAGE,
      "인터페이스 언어 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_BLACK_FRAME_INSERTION,
      "프레임 사이 검은 프레임 삽입. 120Hz 디스플레이에서 60Hz 컨텐츠 실행시 고스트 현상을 줄이는데 유용.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FRAME_DELAY,
      "화면 끊김을 감수하면서 지연을 줄임. 수직동기신호 이후 지연 시간(밀리초) 추가.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_HARD_SYNC_FRAMES,
      "'강제 GPU 동기화'사용시 GPU에 앞서 CPU가 먼저 계산할 프레임 수 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MAX_SWAPCHAIN_IMAGES,
      "비디오 드라이버가 지정된 버퍼링 모드를 사용하도록 지시.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MONITOR_INDEX,
      "사용할 디스플레이를 선택.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_AUTO,
      "화면의 정확한 리프레시 비율(Hz) 측정치.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE_POLLED,
      "The refresh rate as reported by the display driver.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SETTINGS,
      "비디오 출력 설정 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_WIFI_SETTINGS,
      "무선 네트워크 검색 및 연결.")
MSG_HASH(MENU_ENUM_SUBLABEL_HELP_LIST,
      "프로그램 작동 방법을 설명.")
MSG_HASH(MSG_APPENDED_DISK,
      "추가 디스크")
MSG_HASH(MSG_APPLICATION_DIR,
      "프로그램 폴더")
MSG_HASH(MSG_APPLYING_CHEAT,
      "치츠 변경 적용.")
MSG_HASH(MSG_APPLYING_SHADER,
      "쉐이더 적용")
MSG_HASH(MSG_AUDIO_MUTED,
      "음소거.")
MSG_HASH(MSG_AUDIO_UNMUTED,
      "음소거 해제.")
MSG_HASH(MSG_AUTOCONFIG_FILE_ERROR_SAVING,
      "autoconf 파일 저장 오류.")
MSG_HASH(MSG_AUTOCONFIG_FILE_SAVED_SUCCESSFULLY,
      "Autoconfig 파일 저장 성공.")
MSG_HASH(MSG_AUTOSAVE_FAILED,
      "자동저장을 초기화 하지 못했습니다.")
MSG_HASH(MSG_AUTO_SAVE_STATE_TO,
      "자동 상태 저장 to")
MSG_HASH(MSG_BLOCKING_SRAM_OVERWRITE,
      "SRAM 덮어쓰기 차단")
MSG_HASH(MSG_BRINGING_UP_COMMAND_INTERFACE_ON_PORT,
      "포트상의 명령 인터페이드 띄우기")
MSG_HASH(MSG_BYTES,
      "bytes")
MSG_HASH(MSG_CANNOT_INFER_NEW_CONFIG_PATH,
      "새 설정 경로를 파악할 수 없습니다. 현재 시간을 사용합니다.")
MSG_HASH(MSG_CHEEVOS_HARDCORE_MODE_ENABLE,
      "하드코어 모드가 사용되면 상태저장 및 뒤로감기 기능을 이용할 수 없습니다.")
MSG_HASH(MSG_COMPARING_WITH_KNOWN_MAGIC_NUMBERS,
      "알려진 매직 넘버와 비교중...")
MSG_HASH(MSG_COMPILED_AGAINST_API,
      "API에 대한 컴파일")
MSG_HASH(MSG_CONFIG_DIRECTORY_NOT_SET,
      "설정파일 경로가 설정되지 않았습니다. 새 설정을 저장할 수 없습니다.")
MSG_HASH(MSG_CONNECTED_TO,
      "연결됨:")
MSG_HASH(MSG_CONTENT_CRC32S_DIFFER,
      "컨텐츠 CRC32가 다름. 다른 게임은 사용할 수 없습니다.")
MSG_HASH(MSG_CONTENT_LOADING_SKIPPED_IMPLEMENTATION_WILL_DO_IT,
      "컨텐츠 불러오기를 건너뛰었습니다. 자체적으로 실행하게 됩니다.")
MSG_HASH(MSG_CORE_DOES_NOT_SUPPORT_SAVESTATES,
      "코어가 상태저장을 지원하지 않습니다.")
MSG_HASH(MSG_CORE_OPTIONS_FILE_CREATED_SUCCESSFULLY,
      "코어 옵션 파일이 성공적으로 생성되었습니다.")
MSG_HASH(MSG_COULD_NOT_FIND_ANY_NEXT_DRIVER,
      "다음 드라이버를 찾을 수 없음")
MSG_HASH(MSG_COULD_NOT_FIND_COMPATIBLE_SYSTEM,
      "호환되는 시스템을 찾지 못했습니다.")
MSG_HASH(MSG_COULD_NOT_FIND_VALID_DATA_TRACK,
      "올바른 데이터 트랙을 찾지 못함")
MSG_HASH(MSG_COULD_NOT_OPEN_DATA_TRACK,
      "데이터 트랙을 열지 못함")
MSG_HASH(MSG_COULD_NOT_READ_CONTENT_FILE,
      "컨텐츠 파일을 읽지 못함")
MSG_HASH(MSG_COULD_NOT_READ_MOVIE_HEADER,
      "동영상 헤더를 읽지 못했습니다.")
MSG_HASH(MSG_COULD_NOT_READ_STATE_FROM_MOVIE,
      "동영상에서 상태를 불러오지 못했습니다.")
MSG_HASH(MSG_CRC32_CHECKSUM_MISMATCH,
      "리플레이 파일 헤더상의 컨텐츠 파일간 CRC32 체크섬이 일치하지 않습니다. 실행시 싱크가 어긋날 수 있습니다.")
MSG_HASH(MSG_CUSTOM_TIMING_GIVEN,
      "사용자 타이밍")
MSG_HASH(MSG_DECOMPRESSION_ALREADY_IN_PROGRESS,
      "압축해제가 이미 진행중입니다.")
MSG_HASH(MSG_DECOMPRESSION_FAILED,
      "압축해제 실패.")
MSG_HASH(MSG_DETECTED_VIEWPORT_OF,
      "감지된 뷰포트:")
MSG_HASH(MSG_DID_NOT_FIND_A_VALID_CONTENT_PATCH,
      "올바른 컨텐츠 경로를 찾지 못했습니다.")
MSG_HASH(MSG_DISCONNECT_DEVICE_FROM_A_VALID_PORT,
      "장치 연결해제.")
MSG_HASH(MSG_DISK_CLOSED,
      "닫힘")
MSG_HASH(MSG_DISK_EJECTED,
      "꺼냄")
MSG_HASH(MSG_DOWNLOADING,
      "다운로드 중")
MSG_HASH(MSG_DOWNLOAD_FAILED,
      "다운로드 실패")
MSG_HASH(MSG_ERROR,
      "오류")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_CONTENT,
      "Libretro 코어는 실행할 컨텐츠가 필요합니다.")
MSG_HASH(MSG_ERROR_LIBRETRO_CORE_REQUIRES_SPECIAL_CONTENT,
      "Libretro 코어에는 특별한 컨텐츠가 필요하지만 제공된 것이 없습니다.")
MSG_HASH(MSG_ERROR_PARSING_ARGUMENTS,
      "인수 분석 오류.")
MSG_HASH(MSG_ERROR_SAVING_CORE_OPTIONS_FILE,
      "코어 옵션 파일 저장 오류.")
MSG_HASH(MSG_ERROR_SAVING_REMAP_FILE,
      "코어 입렵설정 파일 저장 오류.")
MSG_HASH(MSG_ERROR_SAVING_SHADER_PRESET,
      "쉐이더 프리셋 저장 오류.")
MSG_HASH(MSG_EXTERNAL_APPLICATION_DIR,
      "외부 앱 경로")
MSG_HASH(MSG_EXTRACTING,
      "압축해제 중")
MSG_HASH(MSG_EXTRACTING_FILE,
      "파일 압축해제")
MSG_HASH(MSG_FAILED_SAVING_CONFIG_TO,
      "설정 저장 오류:")
MSG_HASH(MSG_FAILED_TO,
      "실패:")
MSG_HASH(MSG_FAILED_TO_ACCEPT_INCOMING_SPECTATOR,
      "구분자 수신 실패.")
MSG_HASH(MSG_FAILED_TO_ALLOCATE_MEMORY_FOR_PATCHED_CONTENT,
      "패치된 컨텐츠의 메모리 할당 실패...")
MSG_HASH(MSG_FAILED_TO_APPLY_SHADER,
      "쉐이더 적용 실패.")
MSG_HASH(MSG_FAILED_TO_BIND_SOCKET,
      "소켓 연결 실패.")
MSG_HASH(MSG_FAILED_TO_CREATE_THE_DIRECTORY,
      "디렉토리 생성 실패.")
MSG_HASH(MSG_FAILED_TO_EXTRACT_CONTENT_FROM_COMPRESSED_FILE,
      "압축파일에서 컨텐츠 추출 실패")
MSG_HASH(MSG_FAILED_TO_GET_NICKNAME_FROM_CLIENT,
      "클라이언트에서 별칭 얻어오기 실패.")
MSG_HASH(MSG_FAILED_TO_LOAD,
      "불러오기 실패")
MSG_HASH(MSG_FAILED_TO_LOAD_CONTENT,
      "컨텐츠 불러오기 실패")
MSG_HASH(MSG_FAILED_TO_LOAD_MOVIE_FILE,
      "동영상 파일 불러오기 실패")
MSG_HASH(MSG_FAILED_TO_LOAD_OVERLAY,
      "오버레이 불러오기 실패.")
MSG_HASH(MSG_FAILED_TO_LOAD_STATE,
      "상태 불러오기 실패:")
MSG_HASH(MSG_FAILED_TO_OPEN_LIBRETRO_CORE,
      "libretro 코어 불러오기 실패")
MSG_HASH(MSG_FAILED_TO_PATCH,
      "패치 실패")
MSG_HASH(MSG_FAILED_TO_RECEIVE_HEADER_FROM_CLIENT,
      "클라이언트에서 헤더 수신 실패.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME,
      "이름 수신 실패.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_FROM_HOST,
      "호스트에서 이름 수신 실패.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_NICKNAME_SIZE_FROM_HOST,
      "호스트에서 이름 크기 수신 실패.")
MSG_HASH(MSG_FAILED_TO_RECEIVE_SRAM_DATA_FROM_HOST,
      "호스트에서 SRAM 데이터 수신 실패.")
MSG_HASH(MSG_FAILED_TO_REMOVE_DISK_FROM_TRAY,
      "트래이에서 디스크 제거 실패.")
MSG_HASH(MSG_FAILED_TO_REMOVE_TEMPORARY_FILE,
      "임시파일 삭제 실패")
MSG_HASH(MSG_FAILED_TO_SAVE_SRAM,
      "SRAM 세이브 실패")
MSG_HASH(MSG_FAILED_TO_SAVE_STATE_TO,
      "상태저장 저장 실패:")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME,
      "이름 전송 실패.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_SIZE,
      "이름 크기 전송 실패.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_CLIENT,
      "클라이언트에 이름 전달 실패.")
MSG_HASH(MSG_FAILED_TO_SEND_NICKNAME_TO_HOST,
      "호스트에 이름 전달 실패.")
MSG_HASH(MSG_FAILED_TO_SEND_SRAM_DATA_TO_CLIENT,
      "클라이언트에 SRAM 데이터 전송 실패.")
MSG_HASH(MSG_FAILED_TO_START_AUDIO_DRIVER,
      "오디오 드라이버 시작 실패. 오디오 없이 진행됩니다.")
MSG_HASH(MSG_FAILED_TO_START_MOVIE_RECORD,
      "동영상 녹화 실패.")
MSG_HASH(MSG_FAILED_TO_START_RECORDING,
      "녹화 시작 실패.")
MSG_HASH(MSG_FAILED_TO_TAKE_SCREENSHOT,
      "스크린샷 저장 실패.")
MSG_HASH(MSG_FAILED_TO_UNDO_LOAD_STATE,
      "상태저장 불러오기 취소 실패.")
MSG_HASH(MSG_FAILED_TO_UNDO_SAVE_STATE,
      "상태저장 되돌리기 실패.")
MSG_HASH(MSG_FAILED_TO_UNMUTE_AUDIO,
      "음소거 실패.")
MSG_HASH(MSG_FATAL_ERROR_RECEIVED_IN,
      "수신중 치명적 오류:")
MSG_HASH(MSG_FILE_NOT_FOUND,
      "파일 없음")
MSG_HASH(MSG_FOUND_AUTO_SAVESTATE_IN,
      "자동 상태저장 발견:")
MSG_HASH(MSG_FOUND_DISK_LABEL,
      "디스크 라벨 발견")
MSG_HASH(MSG_FOUND_FIRST_DATA_TRACK_ON_FILE,
      "파일상 첫 데이터 트랙 발견")
MSG_HASH(MSG_FOUND_LAST_STATE_SLOT,
      "최근 상태저장 슬롯 발견")
MSG_HASH(MSG_FOUND_SHADER,
      "쉐이더 발견")
MSG_HASH(MSG_FRAMES,
      "프레임")
MSG_HASH(MSG_GAME_SPECIFIC_CORE_OPTIONS_FOUND_AT,
      "게임별 옵션: 게임 특정 코어옵션 발견:")
MSG_HASH(MSG_GOT_INVALID_DISK_INDEX,
      "잘못된 디스크 인덱스 수신.")
MSG_HASH(MSG_GRAB_MOUSE_STATE,
      "마우스 상태")
MSG_HASH(MSG_GAME_FOCUS_ON,
      "게임 포커스 사용")
MSG_HASH(MSG_GAME_FOCUS_OFF,
      "게임 포커스 사용안함")
MSG_HASH(MSG_HW_RENDERED_MUST_USE_POSTSHADED_RECORDING,
      "Libretro 코어는 렌더링 된 하드웨어입니다. 쉐이드 후처리된 녹화를 사용하십시오.")
MSG_HASH(MSG_INFLATED_CHECKSUM_DID_NOT_MATCH_CRC32,
      "체크섬이 CRC32와 일치하지 않습니다.")
MSG_HASH(MSG_INPUT_CHEAT,
      "치트 입력")
MSG_HASH(MSG_INPUT_CHEAT_FILENAME,
      "치트 파일명")
MSG_HASH(MSG_INPUT_PRESET_FILENAME,
      "프리셋 파일명")
MSG_HASH(MSG_INPUT_RENAME_ENTRY,
      "Rename Title")
MSG_HASH(MSG_INTERFACE,
      "인터페이스")
MSG_HASH(MSG_INTERNAL_STORAGE,
      "내부 저장공간")
MSG_HASH(MSG_REMOVABLE_STORAGE,
      "저장공간 삭제")
MSG_HASH(MSG_INVALID_NICKNAME_SIZE,
      "잘못된 별칭 길이.")
MSG_HASH(MSG_IN_BYTES,
      "(바이트)")
MSG_HASH(MSG_IN_GIGABYTES,
      "(기가바이트)")
MSG_HASH(MSG_IN_MEGABYTES,
      "(메가바이트)")
MSG_HASH(MSG_LIBRETRO_ABI_BREAK,
      "현재 libretro 용이 아닌 다른 버전의 libretro로 컴파일되었습니다..")
MSG_HASH(MSG_LIBRETRO_FRONTEND,
      "libretro 프론트엔드")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT,
      "#%d 슬롯에서 상태 불러옴.")
MSG_HASH(MSG_LOADED_STATE_FROM_SLOT_AUTO,
      "#-1 슬롯(자동)에서 상태 불러옴.")
MSG_HASH(MSG_LOADING,
      "불러오는중")
MSG_HASH(MSG_FIRMWARE,
      "하나 이상의 펌웨어 파일이 부족")
MSG_HASH(MSG_LOADING_CONTENT_FILE,
      "컨텐츠 파일 불러오는 중")
MSG_HASH(MSG_LOADING_HISTORY_FILE,
      "실행목록 파일 불러오는 중")
MSG_HASH(MSG_LOADING_STATE,
      "상태저장 불러오는 중")
MSG_HASH(MSG_MEMORY,
      "메모리")
MSG_HASH(MSG_MOVIE_FILE_IS_NOT_A_VALID_BSV1_FILE,
      "동영상 파일이 올바른 BSV1 파일이 아닙니다.")
MSG_HASH(MSG_MOVIE_FORMAT_DIFFERENT_SERIALIZER_VERSION,
      "영상 포맷이 다른 버전으로 보입니다. 실패할 가능성이 큽니다.")
MSG_HASH(MSG_MOVIE_PLAYBACK_ENDED,
      "영상 재생 종료됨.")
MSG_HASH(MSG_MOVIE_RECORD_STOPPED,
      "영상 기록 중지중.")
MSG_HASH(MSG_NETPLAY_FAILED,
      "넷플레이 초기화 실패.")
MSG_HASH(MSG_NO_CONTENT_STARTING_DUMMY_CORE,
      "컨텐츠 없이 더미 코어 시작.")
MSG_HASH(MSG_NO_SAVE_STATE_HAS_BEEN_OVERWRITTEN_YET,
      "덮어씌운 상태 저장 파일은 없습니다.")
MSG_HASH(MSG_NO_STATE_HAS_BEEN_LOADED_YET,
      "불러온 상태 저장 파일이 없습니다.")
MSG_HASH(MSG_OVERRIDES_ERROR_SAVING,
      "우선 설정 저장 오류.")
MSG_HASH(MSG_OVERRIDES_SAVED_SUCCESSFULLY,
      "우선 설정 파일 저장 성공.")
MSG_HASH(MSG_PAUSED,
      "일시정지됨.")
MSG_HASH(MSG_PROGRAM,
      "RetroArch")
MSG_HASH(MSG_READING_FIRST_DATA_TRACK,
      "첫 데이터 트랙 읽는 중...")
MSG_HASH(MSG_RECEIVED,
      "받음")
MSG_HASH(MSG_RECORDING_TERMINATED_DUE_TO_RESIZE,
      "리사이즈 때문에 기록 중지됨.")
MSG_HASH(MSG_RECORDING_TO,
      "다음에 녹화")
MSG_HASH(MSG_REDIRECTING_CHEATFILE_TO,
      "치트 파일 리다이렉션:")
MSG_HASH(MSG_REDIRECTING_SAVEFILE_TO,
      "세이브 파일 리다이렉션:")
MSG_HASH(MSG_REDIRECTING_SAVESTATE_TO,
      "상태저장 파일 리다이렉션:")
MSG_HASH(MSG_REMAP_FILE_SAVED_SUCCESSFULLY,
      "입력설정 파일 저장 성공.")
MSG_HASH(MSG_REMOVED_DISK_FROM_TRAY,
      "트레이에서 디스크 제거됨.")
MSG_HASH(MSG_REMOVING_TEMPORARY_CONTENT_FILE,
      "임시 컨텐츠 파일 제거중")
MSG_HASH(MSG_RESET,
      "초기화")
MSG_HASH(MSG_RESTARTING_RECORDING_DUE_TO_DRIVER_REINIT,
      "드라이버 초기화로 레코딩 다시 시작.")
MSG_HASH(MSG_RESTORED_OLD_SAVE_STATE,
      "이전 상태저장 복원.")
MSG_HASH(MSG_RESTORING_DEFAULT_SHADER_PRESET_TO,
      "쉐이더: 기본 쉐이터 프리셋 복구-")
MSG_HASH(MSG_REVERTING_SAVEFILE_DIRECTORY_TO,
      "세이브 파일 디렉토리 되돌리기:")
MSG_HASH(MSG_REVERTING_SAVESTATE_DIRECTORY_TO,
      "상태저장 파일 디렉토리 되돌리기:")
MSG_HASH(MSG_REWINDING,
      "뒤로감기")
MSG_HASH(MSG_REWIND_INIT,
      "뒤로감기 버퍼크기 초기화:")
MSG_HASH(MSG_REWIND_INIT_FAILED,
      "뒤로감기 버퍼 초기화 실패. 뒤로감기가 비활성 됩니다.")
MSG_HASH(MSG_REWIND_INIT_FAILED_THREADED_AUDIO,
      "스레드된 오디오 구현중. 뒤로감기 사용 불가.")
MSG_HASH(MSG_REWIND_REACHED_END,
      "뒤로감기 버퍼 끝에 도달했습니다.")
MSG_HASH(MSG_SAVED_NEW_CONFIG_TO,
      "새 설정 저장:")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT,
      "슬롯 #%d에 상태저장.")
MSG_HASH(MSG_SAVED_STATE_TO_SLOT_AUTO,
      "슬롯 #-1에 상태저장(자동).")
MSG_HASH(MSG_SAVED_SUCCESSFULLY_TO,
      "저장 성공:")
MSG_HASH(MSG_SAVING_RAM_TYPE,
      "RAM 형식 기록중")
MSG_HASH(MSG_SAVING_STATE,
      "상태저장 중")
MSG_HASH(MSG_SCANNING,
      "검색 중")
MSG_HASH(MSG_SCANNING_OF_DIRECTORY_FINISHED,
      "디렉토리 검색 완료")
MSG_HASH(MSG_SENDING_COMMAND,
      "명령 전달중")
MSG_HASH(MSG_SEVERAL_PATCHES_ARE_EXPLICITLY_DEFINED,
      "여러 패치가 정의되었습니다. 모두 무시합니다...")
MSG_HASH(MSG_SHADER,
      "쉐이더")
MSG_HASH(MSG_SHADER_PRESET_SAVED_SUCCESSFULLY,
      "쉐이서 프리셋 저장 성공.")
MSG_HASH(MSG_SKIPPING_SRAM_LOAD,
      "SRAM 불러오기 건너뛰는 중.")
MSG_HASH(MSG_SLOW_MOTION,
      "슬로우 모션.")
MSG_HASH(MSG_FAST_FORWARD,
      "빨리 감기.")
MSG_HASH(MSG_SLOW_MOTION_REWIND,
      "슬로우 모션 되감기.")
MSG_HASH(MSG_SRAM_WILL_NOT_BE_SAVED,
      "SRAM은 저장되지 않습니다.")
MSG_HASH(MSG_STARTING_MOVIE_PLAYBACK,
      "동영상 재생.")
MSG_HASH(MSG_STARTING_MOVIE_RECORD_TO,
      "동영상 녹화 시작:")
MSG_HASH(MSG_STATE_SIZE,
      "상태저장 크기")
MSG_HASH(MSG_STATE_SLOT,
      "상태 슬롯")
MSG_HASH(MSG_TAKING_SCREENSHOT,
      "스크린샷 저장중.")
MSG_HASH(MSG_TO,
      "to")
MSG_HASH(MSG_UNDID_LOAD_STATE,
      "상태저장 불러오기 취소.")
MSG_HASH(MSG_UNDOING_SAVE_STATE,
      "상태저장 되돌리기")
MSG_HASH(MSG_UNKNOWN,
      "알수없음")
MSG_HASH(MSG_UNPAUSED,
      "일시정지 해제.")
MSG_HASH(MSG_UNRECOGNIZED_COMMAND,
      "알 수 없는 명령")
MSG_HASH(MSG_USING_CORE_NAME_FOR_NEW_CONFIG,
      "새 설정에 코어이름 사용.")
MSG_HASH(MSG_USING_LIBRETRO_DUMMY_CORE_RECORDING_SKIPPED,
      "libretro 더미코어 사용. 녹화 생략.")
MSG_HASH(MSG_VALUE_CONNECT_DEVICE_FROM_A_VALID_PORT,
      "이용가능한 포트로 장치 접속.")
MSG_HASH(MSG_VALUE_DISCONNECTING_DEVICE_FROM_PORT,
      "포트에서 장치연결 해제")
MSG_HASH(MSG_VALUE_REBOOTING,
      "다시 시작 중...")
MSG_HASH(MSG_VALUE_SHUTTING_DOWN,
      "종료 중...")
MSG_HASH(MSG_VERSION_OF_LIBRETRO_API,
      "libretro API 버전")
MSG_HASH(MSG_VIEWPORT_SIZE_CALCULATION_FAILED,
      "뷰포트 크기 계산 실패! 원시 데이터를 계속 사용합니다. 정상 적인 동작을 보장할 수 없습니다...")
MSG_HASH(MSG_VIRTUAL_DISK_TRAY,
      "가상 디스크 트레이.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_LATENCY,
      "원하는 오디오 지연(밀리초). 오디오 드라이버가 해당 지연시간을 지원하지 못할 경우 무시될 수 있습니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MUTE,
      "음소거/음소거 해제.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RATE_CONTROL_DELTA,
      "오디오와 비디오를 동기화 할 때 불완전한 타이밍을 완화. 비활성화 시 정상적인 동기화 결과를 얻을 수 없게됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_ALLOW,
      "코어에 의한 카메라 접근을 허용 또는 금지."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_ALLOW,
      "코어에 의한 위치 서비스 접근을 허용 또는 금지."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_MAX_USERS,
      "RetroArch에서 지원 가능한 사용자 수."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_POLL_TYPE_BEHAVIOR,
      "RetroArch 내부에서 입력 폴링이 수행되는 방식. 설정에 따라 지연시간을 줄 일 수 있음."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_ALL_USERS_CONTROL_MENU,
      "모든 사용자가 메뉴를 제어하도록 허용. 비활성 시 사용자 1 만 메뉴를 제어할 수 있습니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_VOLUME,
      "오디오 볼륨(데시벨). 0 dB 설정시 보통, 게인 설정이 적용되지 않은 상태."
      )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_SYNC,
   "오디오 동기화. 사용 권장."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_AXIS_THRESHOLD,
   "축의 기울기가 인식되는 범위를 설정."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_BIND_TIMEOUT,
   "다음 입력 설정으로 넘어가기 전까지 대기하는 시간(초)."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_TURBO_PERIOD,
   "터보 사용 버튼이 눌렸을때 적용되는 터보 간격. 숫자는 프레임."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_INPUT_DUTY_CYCLE,
   "터보 사용 가능 버튼의 동작 기간. 숫자는 프레임."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_VSYNC,
   "그래픽 카드의 비디오 출력을 디스플레이의 화면 재생 빈도와 동기화. 사용 권장."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_ALLOW_ROTATE,
   "코어의 화면 회전 설정을 허용. 비활성화하면 회전 요청을 무시하게 되어 수동으로 화면 회전시 유용."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_DUMMY_ON_CORE_SHUTDOWN,
   "코어 자체에 시스템 종료기능을 내장한 경우가 있는데 이 경우 더미 코어를 불러와서 코어가 RetroArch를 종료하지 못하게 방지합니다."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_CHECK_FOR_MISSING_FIRMWARE,
   "콘텐츠를 불러오기 전에 필요한 펌웨어가 모두 있는지 확인."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_VIDEO_REFRESH_RATE,
   "화면의 수직 재생 빈도. 적절한 오디오 입력 비율을 계산하는데 사용. 참고: '스레드된 비디오'가 활성화 된 경우 무시됩니다."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_ENABLE,
   "오디오 출력 사용."
   )
MSG_HASH(
   MENU_ENUM_SUBLABEL_AUDIO_MAX_TIMING_SKEW,
   "오디오 입력 비율의 최대 변화치. 값을 높이면 부정확 한 오디오 피치와 함께 타이밍을 크게 변형할 수 있습니다.(예: NTSC 디스플레이에서 PAL 코어 실행)."
   )
MSG_HASH(
   MSG_FAILED,
   "실패"
   )
MSG_HASH(
   MSG_SUCCEEDED,
   "성공"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED,
   "설정 안됨"
   )
MSG_HASH(
   MSG_DEVICE_NOT_CONFIGURED_FALLBACK,
   "설정 안됨, 이전으로 복구"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST,
   "데이터베이스 커서 목록"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DEVELOPER,
   "데이터베이스 - 필터 : 개발사"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PUBLISHER,
   "데이터베이스 - 필터 : 발매사"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_DISABLED,
   "사용안함"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_ENABLED,
   "사용"
   )
MSG_HASH(
   MENU_ENUM_LABEL_VALUE_CONTENT_HISTORY_PATH,
   "컨텐츠 실행목록 경로"
   )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ORIGIN,
      "데이터베이스 - 필터 : 단독")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_FRANCHISE,
      "데이터베이스 - 필터 : 프렌차이즈")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ESRB_RATING,
      "데이터베이스 - 필터 : ESRB 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_ELSPA_RATING,
      "데이터베이스 - 필터 : ELSPA 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_PEGI_RATING,
      "데이터베이스 - 필터 : PEGI 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_CERO_RATING,
      "데이터베이스 - 필터 : CERO 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_BBFC_RATING,
      "데이터베이스 - 필터 : BBFC 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_MAX_USERS,
      "데이터베이스 - 필터 : 최대 사용자")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_MONTH,
      "데이터베이스 - 필터 : 월별 출시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_RELEASEDATE_BY_YEAR,
      "데이터베이스 - 필터 : 연간 출시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_ISSUE,
      "데이터베이스 - 필터 : 에지 메거진 기사")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_EDGE_MAGAZINE_RATING,
      "데이터베이스 - 필터 : 에지 매거진 등급")
MSG_HASH(MENU_ENUM_LABEL_VALUE_DATABASE_CURSOR_LIST_ENTRY_DATABASE_INFO,
      "데이터베이스 정보")
MSG_HASH(MSG_WIFI_SCAN_COMPLETE,
      "Wi-Fi 검색 완료.")
MSG_HASH(MSG_SCANNING_WIRELESS_NETWORKS,
      "무선 네트워크 검색중...")
MSG_HASH(MSG_NETPLAY_LAN_SCAN_COMPLETE,
      "넷플레이 검색 완료.")
MSG_HASH(MSG_NETPLAY_LAN_SCANNING,
      "넷플레이 호스트 검색중...")
MSG_HASH(MENU_ENUM_SUBLABEL_PAUSE_NONACTIVE,
      "RetroArch가 활성 창이 아닐 때 게임 플레이 일시 중지.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_DISABLE_COMPOSITION,
      "데스크탑 구성요서 활성화 또는 비활성화. (Windows에만 해당)")
MSG_HASH(MENU_ENUM_SUBLABEL_HISTORY_LIST_ENABLE,
      "게임, 이미지, 음악 및 비디오의 최근 실행 목록을 활성화 또는 비활성화.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_HISTORY_SIZE,
      "게임, 이미지, 음악 및 비디오의 최근 실행 목록 항목 수를 제한.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_INPUT_UNIFIED_MENU_CONTROLS,
      "통합 메뉴 컨트롤")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_UNIFIED_MENU_CONTROLS,
      "메뉴와 게임 모두에 동일한 컨트롤을 사용. 키보드에 적용됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_ENABLE,
      "온스크린 메시지 표시.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETWORK_USER_REMOTE_ENABLE,
      "사용자 %d 원격 사용")
MSG_HASH(MENU_ENUM_LABEL_VALUE_BATTERY_LEVEL_ENABLE,
      "배터리 수준 표시")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FILE,
      "파일 선택")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SELECT_FROM_COLLECTION,
      "컬렉션에서 선택")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER,
      "필터")
MSG_HASH(MENU_ENUM_LABEL_VALUE_SCALE,
      "크기")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_START_WHEN_LOADED,
      "컨텐츠가 불러와지면 넷플레이가 시작됩니다.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_LOAD_CONTENT_MANUALLY,
      "적합한 코어 또는 컨텐츠 파일을 찾지 못했습니다. 수동으로 불러오십시오.")
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL_LIST,
      "URL 탐색"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_URL,
      "URL 경로"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_BROWSE_START,
      "시작"
      )
MSG_HASH(MENU_ENUM_LABEL_VALUE_SHADER_PIPELINE_BOKEH,
      "보케")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_REFRESH_ROOMS,
      "새로 고침")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME,
      "사용자: %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_ROOM_NICKNAME_LAN,
      "사용자 (랜): %s")
MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_COMPAT_CONTENT_FOUND,
      "호환 가능한 컨텐츠 발견")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_CROP_OVERSCAN,
      "불필요 픽셀을 포함해 개발자가 숨겨지길 원했던 가장자리 주변 픽셀을 잘라냄.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SMOOTH,
      "픽셀 가장자리의 날카로운 부분을 줄이기 위해 이미지에 약간의 흐림 효과를 추가. 이 옵션은 성능에 거의 영향을 주지 않습니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FILTER,
      "CPU가 처리하는 비디오 필터를 적용. 참고:성능에 큰 희생이 필요할 수 있습니다. 일부 필터는 32비트 또는 16비트 색상을 사용하는 코어에만 적용될 수 있음")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_USERNAME,
      "레트로 도전과제 계정 사용자 이름 입력.")
MSG_HASH(MENU_ENUM_SUBLABEL_CHEEVOS_PASSWORD,
      "레트로 도전과제 계정 비밀번호 입력.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_NICKNAME,
      "여기에 사용자 이름을 입력하십시오. 넷플레이 세션등에 사용됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_POST_FILTER_RECORD,
      "필터가 적용된 이미지를 캡쳐(쉐이더는 제외). 화면상에 보이는 것 그대로 멋지게 적용됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_LIST,
      "사용할 코어 선택.")
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_CONTENT_LIST,
      "실행할 컨텐츠 선택.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETWORK_INFORMATION,
      "네트워크 인터페이스 및 연결된 IP 주소 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_INFORMATION,
      "시스템 관련 정보 표시.")
MSG_HASH(MENU_ENUM_SUBLABEL_QUIT_RETROARCH,
      "프로그램 종료.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_WIDTH,
      "표시 창의 사용자 너비 크기 설정. 값을 0으로 두면 최대 크기로 창을 설정합니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_WINDOW_HEIGHT,
      "표시 창의 사용자 높이 크기 설정. 값을 0으로 두면 최대 크기로 창을 설정합니다..")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_X,
      "OSD 문자 위치를 위한 사용자 X좌표 지정.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_MESSAGE_POS_Y,
      "OSD 문자 위치를 위한 사용자 Y좌표 지정.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_SIZE,
      "포인트 단위로 폰트 크기 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_OVERLAY_HIDE_IN_MENU,
      "메뉴 화면에서 오버레이를 숨기고 메뉴 종료 시에 다시 표시.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_COLLECTION_LIST,
      "검색된 컨텐츠가 이곳에 표시됨."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SCALE_INTEGER,
      "정수 단위로만 비디오의 크기를 조정. 기본 크기는 시스템에 보고 된 크기와 종횡비에 따라 다르며 '강제 화면비'가 설정되지 않는한 X/Y 각각이 정수단위로 크기가 조절됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_SCREENSHOT,
      "가능한 경우 GPU 쉐이더 처리된 화면 스크린샷을 저장."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_ROTATION,
      "강제로 화면을 회전시킴. 코어 기본 회전 설정에 추가로 회전."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FORCE_SRGB_DISABLE,
      "sRGB FBO 지원을 강제로 비활성. Windows에서 일부 인텔 OpenGL 드라이버가 sRGB FBO에서 문제가 발생하는데 활성화시 이 문제를 우회할 수 있습니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FULLSCREEN,
      "전체화면으로 시작. 실행 중 변경 가능."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_WINDOWED_FULLSCREEN,
      "전체화면에서 전체 창화면을 선호."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_GPU_RECORD,
      "가능할시 GPU 쉐이더 처리된 출력을 녹화."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_INDEX,
      "상태저장 생성시 자동으로 인덱스를 추가 저장. 불러올 시에는 가장 높은 숫자의 인덱스로 설정."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BLOCK_SRAM_OVERWRITE,
      "상태저장 파일을 불러올때 SaveRAM을 덮어 쓰는 걸 방지. 잠재적으로 버그가 많은 게임이 될 수 있음."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_FASTFORWARD_RATIO,
      "빨리 감기를 사용할 때 콘텐츠가 실행되는 최대 속도. (예: 60fps 콘텐츠의 경우 5.0x = 300fps) 0.0x로 설정하면 빨리감기 속도는 무제한이 됩니다. (FPS 제한 없음)"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SLOWMOTION_RATIO,
      "슬로우 모션 일 때 콘텐츠가 지정된 수치 만큼 느려집니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_ENABLE,
      "뒤로감기 사용. 플레이시 퍼포먼스 저하가 생길 수 있습니다. "
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_REWIND_GRANULARITY,
      "뒤로감는데 사용하는 프레임 수. 한 번에 여러 프레임을 되감기하여 속도를 올릴 수 있습니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LIBRETRO_LOG_LEVEL,
      "코어의 로그 수준을 설정. 코어에서 발생하는 설정값 이하의 로그수준은 무시됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PERFCNT_ENABLE,
      "RetroArch 및 코어의 성능 카운터 사용."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_SAVE,
      "RetroArch의 실행이 종료되면 자동으로 상태저장 파일을 생성. 자동 상태 불러오기를 활성화 시키면 다음 시작시 해당 상태저장을 자동으로 불러옵니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_AUTO_LOAD,
      "시작시 자동 상태저장 파일 불러오기."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_SAVESTATE_THUMBNAIL_ENABLE,
      "메뉴에 상태저장 미리보기 보이기."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTOSAVE_INTERVAL,
      "비휘발성 SaveRAM을 정기적으로 자동 저장. 기본값은 비활성이며 기간은 초 단위. 0으로 설정시 자동저장이 비활성됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_REMAP_BINDS_ENABLE,
      "사용시 재설정된 입력설정이 현재 코어에 설정된 입력에 우선하게 됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_AUTODETECT_ENABLE,
      "입력 자동감지 사용. 조이패드를 자동으로 구성해줍니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_INPUT_SWAP_OK_CANCEL,
      "확인/취소 버튼을 교환. 비활성시 일본식 버튼 구성이되고 사용시 서양식 구성으로 설정됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_PAUSE_LIBRETRO,
      "사용하지 않으면 RetroArch 메뉴 호출시에도 컨텐츠가 백그라운드에서 계속 실행됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_DRIVER,
      "사용할 비디오 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DRIVER,
      "사용할 오디오 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_DRIVER,
      "사용할 입력 드라이버. 비디오 드라이버에 따라 다른 입력 드라버를 사용해야 할 수 있음."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_JOYPAD_DRIVER,
      "사용할 조이패드 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_DRIVER,
      "사용할 오디오 리셈플러 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CAMERA_DRIVER,
      "사용할 카메라 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_LOCATION_DRIVER,
      "사용할 위치 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_DRIVER,
      "사용할 메뉴 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_RECORD_DRIVER,
      "사용할 녹화 드라이버."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_WIFI_DRIVER,
      "사용할 WiFi."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_BROWSER_FILTER_SUPPORTED_EXTENSIONS_ENABLE,
      "지원되는 확장자 기준으로 파일 탐색기에 표시."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MENU_WALLPAPER,
      "메뉴 배경으로 사용할 이미지 선택."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPER,
      "컨텍스트에 따라 새로운 배경화면을 동적으로 불러오기."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DEVICE,
      "오디오 드라이버가 사용하는 기본 오디오 장치를 다시 설정. 드라이버 종속 옵션."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_DSP_PLUGIN,
      "드라이버로 보내기 전에 오디오를 처리하는 오디오 DSP 플러그인."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_OUTPUT_RATE,
      "오디오 출력 샘플레이트."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_OPACITY,
      "오버레이의 모든 UI 요소에 대한 불투명도."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_SCALE,
      "오버레이에 사용할 전체 UI 구성요소의 크기."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_INPUT_OVERLAY_ENABLE,
      "오버레이를 사용."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_OVERLAY_PRESET,
      "파일 탐색기에서 오버레이 선택."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_IP_ADDRESS,
      "연결할 호스트 주소."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_TCP_UDP_PORT,
      "호스트 IP 주소의 포트. TCP 또는 UDP 포트."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PASSWORD,
      "넷플레이 호스트에 연결하기 위한 비밀번호. 호스트 모드에서만 사용됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_PUBLIC_ANNOUNCE,
      "넷플레이 게임을 공개로 할것인지 여부. 설정하지 않으면 클라이언트는 공용 로비를 사용하지 않고 수동으로 연결해야합니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_SPECTATE_PASSWORD,
      "관전 권한만 있는 넷플레이 호스트에 연결하기 위한 비밀번호. 호스트 모드에서만 사용됩니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_START_AS_SPECTATOR,
      "넷플레이를 관전 모드로 실행할지 선택."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ALLOW_SLAVES,
      "슬레이브 모드 연결을 허용할지 여부. 슬레이브 모드 클라이언트는 양측에 처리능력이 거의 필요하지 않지만 네트워크 지연을 겪을 수 있습니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_REQUIRE_SLAVES,
      "슬레이브 모드가 아닌 연결을 허용하지 않을지 여부. 낮은 성능의 컴퓨터에 매우 빠른 네트워크를 제외하고는 권장하지 않습니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_STATELESS_MODE,
      "상태저장이 필요없는 모드로 넷틀레이를 실행할지 여부. 설정할 경우 빠른 네트워크가 필요하지만 되감기가 불가능하여 넷플레이 지터는 발생하지 않습니다."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_CHECK_FRAMES,
      "넷플레이가 호스트와 클라이언트가 동기화 중인지 확인하는 프레임의 빈도."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_NAT_TRAVERSAL,
      "호스팅 할 때 UPnP 또는 유사 기술을 사용하여 공용 인터넷에서 연결 수신 대기."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_STDIN_CMD_ENABLE,
      "표준입력 명령어 인터페이스 사용."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_MOUSE_ENABLE,
      "메뉴에서 마우스 사용."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_POINTER_ENABLE,
      "메뉴에서 터치 컨트로 사용."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_THUMBNAILS,
      "표시할 미리보기 종류."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_TIMEDATE_ENABLE,
      "메뉴에 현재 시간 및 날짜 표시."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_BATTERY_LEVEL_ENABLE,
      "메뉴에 현재 배터리 상태 표시."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NAVIGATION_WRAPAROUND,
      "가로 또는 세로 목록의 끝에 도달하면 시작 또는 끝으로 이어서 연결."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_HOST,
      "호스트(서버)모드로 넷플레이 사용."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_ENABLE_CLIENT,
      "클라이언트 모드로 넷플레이 사용.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_DISCONNECT,
      "활성 중인 모든 넷플레이 연결 해제.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_DIRECTORY,
      "디렉토리에서 실행 가능한 파일을 검색하고 컬렉션에 추가.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCAN_FILE,
      "실행 가능한 파일을 검색하고 컬렉션에 추가.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SWAP_INTERVAL,
      "수직 동기에 사용자 스왑 간격을 사용. 모니터 재생 빈도를 효과적으로 줄이는데 사용."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVEFILES_ENABLE,
      "코어 이름 폴더별로 저장된 세이브파일을 정렬."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SORT_SAVESTATES_ENABLE,
      "코어 이름 폴더별로 저장된 상태저장파일 정렬."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_BUILDBOT_URL,
      "Libretro 빌드봇 상의 코어 업데이터 디렉토리 URL.")
MSG_HASH(MENU_ENUM_SUBLABEL_BUILDBOT_ASSETS_URL,
      "Libretro 빌드봇 상의 애셋 업데이터 디렉토리 URL.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_UPDATER_AUTO_EXTRACT_ARCHIVE,
      "다운로드 완료후 자동으로 압축 해제."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_REFRESH_ROOMS,
      "새 호스트 검색.")
MSG_HASH(MENU_ENUM_SUBLABEL_DELETE_ENTRY,
      "컬렉션에서 현재 항목 삭제.")
MSG_HASH(MENU_ENUM_SUBLABEL_INFORMATION,
      "컨텐츠에 대한 자세한 정보 확인.")
MSG_HASH(MENU_ENUM_SUBLABEL_RUN,
      "컨텐츠 시작.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FILE_BROWSER_SETTINGS,
      "파일 탐색기 설정 변경.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_REMAPS_ENABLE,
      "시작시 사용자 입력설정을 기본으로 사용."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUTO_OVERRIDES_ENABLE,
      "시작시 사용자 코어 옵션을 기본으로 사용."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_GAME_SPECIFIC_OPTIONS,
      "시작시 사용자 설정파일을 기본으로 사용.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ENABLE,
      "메뉴에 현재 사용 코어이름을 표시.")
MSG_HASH(MENU_ENUM_SUBLABEL_DATABASE_MANAGER,
      "데이터베이스 보기.")
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_MANAGER,
      "이전의 검색 내용 보기.")
MSG_HASH(MENU_ENUM_SUBLABEL_TAKE_SCREENSHOT,
      "화면 이미지를 캡쳐.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CLOSE_CONTENT,
      "현재 컨텐츠 종료. 저장하지 않은 내용은 사라지게됩니다."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_LOAD_STATE,
      "현재 선택된 슬롯에서 상태저장 파일 불러오기.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_STATE,
      "현재 선택된 슬롯에 상태저장 파일 기록.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME,
      "빠른 메뉴를 종료하고  현재 실행 중인 컨텐츠 이어하기.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESUME_CONTENT,
      "빠른 메뉴를 종료하고 현재 실행 중인 컨텐츠 이어하기")
MSG_HASH(MENU_ENUM_SUBLABEL_STATE_SLOT,
      "현재 선택된 저장 슬롯을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_LOAD_STATE,
      "상태저장 파일을 불러왔을때, 불러오기 이전 상태로 되돌리기.")
MSG_HASH(MENU_ENUM_SUBLABEL_UNDO_SAVE_STATE,
      "상태저장 파일을 덮어씌웠을때, 이전 저장 상태로 되돌리기.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_RETRO_ACHIEVEMENTS,
      "레트로 도전과제 서비스. 자세한 정보는 http://retroachievements.org 방문."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ACCOUNTS_LIST,
      "현재 설정된 계정을 관리."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_META_REWIND,
      "뒤로감기 설정 관리.")
MSG_HASH(MENU_ENUM_SUBLABEL_RESTART_CONTENT,
      "컨텐츠를 처음부터 다시 시작.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_CORE,
      "현재 코어로 실행되는 모든 컨텐츠에 적용할 우선설정 저장. 기본 설정에 우선하여 적용됨.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVE_CURRENT_CONFIG_OVERRIDE_GAME,
      "현재 컨텐츠에 한정해 적용되는 우선 설정 저장. 기본 설정에 우선하여 적용됨.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_CHEAT_OPTIONS,
      "치트 코드 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_OPTIONS,
      "화면에 시각적으로 더해질 쉐이더 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INPUT_REMAPPING_OPTIONS,
      "현재 실행중인 컨텐츠의 조작방법 설정을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_OPTIONS,
      "현재 실행중인 컨텐츠의 옵션을 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHOW_ADVANCED_SETTINGS,
      "파워 유저를 위한 고급 설정 보이기(기본값은 숨김).")
MSG_HASH(MENU_ENUM_SUBLABEL_THREADED_DATA_RUNLOOP_ENABLE,
      "분할된 스레드에서 작업을 수행.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_REMOVE,
      "사용자가 컬렉션에서 항목을 제거할 수 있게 허용.")
MSG_HASH(MENU_ENUM_SUBLABEL_SYSTEM_DIRECTORY,
      "시스템 디렉토리를 설정. 코어는 이 디렉토리에서 BIOS, 시스템 특정 구성 등을 불러들일 수 있습니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_BROWSER_DIRECTORY,
      "파일 탐색기의 시작 디렉토리를 설정.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DIR,
      "일반적으로 libretro/RetroArch 앱과 애셋을 묶은 개발자가 설정합니다."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_DYNAMIC_WALLPAPERS_DIRECTORY,
      "컨텍스트에 따라 메뉴가 동적으로 불러오게될 배경화면 디렉토리.")
MSG_HASH(MENU_ENUM_SUBLABEL_THUMBNAILS_DIRECTORY,
      "부가적인 미리보기 이미지 저장공간 (박스아트/기타, 이미지 등)."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_CONFIG_DIRECTORY,
      "메뉴 환경설정 디렉토리 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_MIN,
      "넷플레이가 네트워크 지연을 숨기기 위해 사용하는 지연 프레임 수. 입력 지연으로 지터를 줄이고 넷플레이의 CPU 사용을 줄입니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_INPUT_LATENCY_FRAMES_RANGE,
      "네트워크 지연을 숨기기 위해 사용하는 입력 대기 프레임 범위. 예측 불가능한 입력 지연으로 지터를 줄이고 넷플레이의 CPU 사용을 줄입니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_CYCLE_TRAY_STATUS,
      "현재 디스크를 전환. 삽입된 디스크가 있으면 꺼내지고 디스크가 없으면 디스크를 삽입합니다. ")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_INDEX,
      "디스크 인덱스 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_OPTIONS,
      "디스크 이미지 관리.")
MSG_HASH(MENU_ENUM_SUBLABEL_DISK_IMAGE_APPEND,
      "삽입할 디스크 이미지를 선택하십시오.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENUM_THROTTLE_FRAMERATE,
      "메뉴상에 있을 시에는 프레임 제한을 설정.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_LAYOUT,
      "Select a different layout for the XMB interface.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_THEME,
      "다른 아이콘 테마 선택. 변경 내용은 프로그램을 다시 시작 후 적용됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_SHADOWS_ENABLE,
      "모든 아이콘에 그림자 사용. 퍼포먼스에 약간의 영향을 줄 수 있습니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_COLOR_THEME,
      "배경색 그라데이션 테마를 선택.")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_WALLPAPER_OPACITY,
      "배경화면의 투명도 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MENU_COLOR_THEME,
      "배경색 그라데이션 테마 선택.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_RIBBON_ENABLE,
      "애니메이션 배경 효과 선택. 선택한 효과에 따라 GPU 부하를 줄 수 있습니다. 성능에 영향을 주는 경우 기능을 끄거나 간단한 효과로 되돌리십시오.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_FONT,
      "메뉴에 사용할 기본 폰트 선택.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_IMAGES,
      "메인 메뉴에 이미지 탭 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_MUSIC,
      "메인 메뉴에 음악 탭 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_VIDEO,
      "메인 메뉴에 비디오 탭 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_NETPLAY,
      "메인 메뉴에 넷플레이 탭 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS,
      "메인 메뉴에 설정 탭 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_HISTORY,
      "메인 메뉴에 최근 실행목록 탭 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_ADD,
      "메인 메뉴에 컨텐츠 가져오기 탭 보이기.")
MSG_HASH(MENU_ENUM_SUBLABEL_RGUI_SHOW_START_SCREEN,
      "시작 화면을 메뉴에 보이기. 프로그램 첫 실행 후 자동으로 비활성 됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_HEADER_OPACITY,
      "헤더 그래픽의 투명도 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_MENU_FOOTER_OPACITY,
      "푸터 그래픽의 투명도 변경.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_ENABLE,
      "메뉴는 일반적으로 동적으로 조정됩니다. 특정 크기를 설정하려면 이 옵션을 활성화하십시오.")
MSG_HASH(MENU_ENUM_SUBLABEL_DPI_OVERRIDE_VALUE,
      "사용자 정의 크기 조정 설정. 참고:크기조정을 적용하려면 'DPI Override'를 활성화해야합니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_ASSETS_DIRECTORY,
      "모든 다운로드 파일을 이 디렉토리에 저장합니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_INPUT_REMAPPING_DIRECTORY,
      "모든 입력설정 파일이 이 디렉토리에 저장됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_DIR_PATH,
      "프로그램이 컨텐츠/코어를 찾을 디렉토리.")
MSG_HASH(MENU_ENUM_SUBLABEL_LIBRETRO_INFO_PATH,
      "앱/코어 정보 파일이 저장될 공간.")
MSG_HASH(MENU_ENUM_SUBLABEL_JOYPAD_AUTOCONFIG_DIR,
      "조이패드가 연결되면 해당 디렉토리에 설정 파일이 있는 경우 자동으로 구성해줍니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_DIRECTORY,
      "모든 컬렉션이 이 디렉토리에 저장됩니다.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CACHE_DIRECTORY,
      "디렉토리를 설정하면 설정하면 임시로 압축해제된 컨첸츠가 이 디렉토리에 추출됩니다."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CURSOR_DIRECTORY,
      "검색 정보가 저장될 디렉토리.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CONTENT_DATABASE_DIRECTORY,
      "데이터베이스가 저장될 디렉토리."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_ASSETS_DIRECTORY,
      "이 위치에서 메뉴 인터페이스가 애셋 등을 찾을 경우 기본적으로 확인하게됩니다."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_SAVEFILE_DIRECTORY,
      "모든 세이브 파일이 저장될 디렉토리. 설정하지 않을 경우 컨텐츠 파일의 작업 디렉토리에 저장됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_SAVESTATE_DIRECTORY,
      "모든 상태저장 파일이 저장될 디렉토리. 설정하지 않을 경우 컨텐츠 파일의 작업 디렉토리에 저장됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_SCREENSHOT_DIRECTORY,
      "스크린샷을 저장할 디렉토리.")
MSG_HASH(MENU_ENUM_SUBLABEL_OVERLAY_DIRECTORY,
      "쉬운 접근을 위해 오버레이가 저장된 디렉토리를 정의.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_DATABASE_PATH,
      "치트 파일이 저장될 공간."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_FILTER_DIR,
      "오디오 DSP 필터 파일이 저장될 디렉토리."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_FILTER_DIR,
      "CPU기반 비디오 필터가 저장될 디렉토리."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_DIR,
      "쉬운 접근을 위해 GPU기반 비디오 쉐이더가 저장될 디렉토리 정의.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_OUTPUT_DIRECTORY,
      "녹화 내용이 현재 디렉토리에 덤프됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_RECORDING_CONFIG_DIRECTORY,
      "녹화 설정이 이곳에 저장됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_FONT_PATH,
      "온스크링 알림에 사용할 폰트 선택.")
MSG_HASH(MENU_ENUM_SUBLABEL_SHADER_APPLY_CHANGES,
      "쉐이더 설정의 변경사항은 즉시 적용됩니다. 쉐이더 패스 및 필터링, FBO등 많은 부분을 변경했을시 적용.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_VIDEO_SHADER_NUM_PASSES,
      "쉐이더 파이프라인 패스 감소 또는 증가. 각각의 쉐이더를 파이프라인에 연결하고 크기 및 필터링을 변경할 수 있습니다."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET,
      "쉐이더 프리셋 불러오기. 쉐이더 파이프라인이 자동으로 설정됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_AS,
      "현재 쉐이더 설정을 새로운 프리셋으로 저장.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_CORE,
      "현재 쉐이더 설정을 현재 앱/코어의 기본 값으로 저장.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_SAVE_GAME,
      "현재 쉐이더 설정을 컨텐츠의 기본 값으로 저장.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PARAMETERS,
      "현재 쉐이더를 직접 변경. 변경사항이 프리셋 파일로 저장되진 않습니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_SHADER_PRESET_PARAMETERS,
      "현재 메뉴상에서 사용되는 쉐이더를 변경.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_NUM_PASSES,
      "치트 개수 추가 또는 감소."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CHEAT_APPLY_CHANGES,
      "변경된 치트는 즉시 적용됩니다.")
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_LOAD,
      "치트파일 불러오기."
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_CHEAT_FILE_SAVE_AS,
      "현재 치트를 세이브 파일로 저장."
      )
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SETTINGS,
      "관련된 모든 게임 설정에 빠르게 접근.")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_INFORMATION,
      "앱/코어에 관련된 정보 보기.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_HEIGHT,
      "화면 비가 '사용자 설정'으로 되어있을 시 사용할 사용자 뷰포트 높이.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_WIDTH,
      "화면 비가 '사용자 설정'으로 되어있을 시 사용할 사용자 뷰포트 넓이.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_X,
      "뷰포트의 X축 위치를 정의하는 데 사용되는 사용자 뷰포트 오프셋. '정수 단위 화면 크기'가 활성화 된 경우 무시되고 자동으로 중앙이 됩니다.")
MSG_HASH(MENU_ENUM_SUBLABEL_VIDEO_VIEWPORT_CUSTOM_Y,
      "뷰포트의 Y축 위치를 정의하는 데 사용되는 사용자 뷰포트 오프셋. '정수 단위 화면 크기'가 활성화 된 경우 무시되고 자동으로 중앙이 됩니다.")

MSG_HASH(MENU_ENUM_LABEL_VALUE_NETPLAY_USE_MITM_SERVER,
      "Use Relay Server")
MSG_HASH(MENU_ENUM_SUBLABEL_NETPLAY_USE_MITM_SERVER,
      "Forward netplay connections through a man-in-the-middle server. Useful if the host is behind a firewall or has NAT/UPnP problems.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER,
      "Add to mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION,
      "Add to mixer")
MSG_HASH(MENU_ENUM_LABEL_VALUE_ADD_TO_MIXER_AND_COLLECTION_AND_PLAY,
      "Add to mixer and play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_FILTER_BY_CURRENT_CORE,
      "Filter by current core")
MSG_HASH(
      MSG_AUDIO_MIXER_VOLUME,
      "Global audio mixer volume"
      )
MSG_HASH(
      MENU_ENUM_SUBLABEL_AUDIO_MIXER_VOLUME,
      "Global audio mixer volume (in dB). 0 dB is normal volume, and no gain is applied."
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_VOLUME,
      "Audio Mixer Volume Level (dB)"
      )
MSG_HASH(
      MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_MUTE,
      "Audio Mixer Mute"
      )
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_MUTE,
      "Mute/unmute mixer audio.")
MSG_HASH(MENU_ENUM_LABEL_MENU_SHOW_ONLINE_UPDATER,
      "Show Online Updater")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_ONLINE_UPDATER,
      "Show/hide the 'Online Updater' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CORE_UPDATER,
      "Show Core Updater")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CORE_UPDATER,
      "Show/hide the ability to update cores (and core info files).")
MSG_HASH(MSG_PREPARING_FOR_CONTENT_SCAN,
      "Preparing for content scan...")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CORE_DELETE,
      "Delete core")
MSG_HASH(MENU_ENUM_SUBLABEL_CORE_DELETE,
      "Remove this core from disk.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_RENAME_ENTRY,
      "Rename the title of the entry.")
MSG_HASH(MENU_ENUM_LABEL_RENAME_ENTRY,
      "Rename")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_FRAMEBUFFER_OPACITY,
      "Framebuffer Opacity")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_FRAMEBUFFER_OPACITY,
      "Modify the opacity of the framebuffer.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_FAVORITES,
      "Favorites")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_FAVORITES,
      "Content which you have added to 'Favorites' will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_MUSIC,
      "Music")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_MUSIC,
      "Music which has been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_IMAGES,
      "Image")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_IMAGES,
      "Images which have been previously viewed will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_GOTO_VIDEO,
      "Video")
MSG_HASH(MENU_ENUM_SUBLABEL_GOTO_VIDEO,
      "Videos which have been previously played will appear here.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MATERIALUI_ICONS_ENABLE,
      "Menu Icons")
MSG_HASH(MENU_ENUM_SUBLABEL_MATERIALUI_ICONS_ENABLE,
      "Enable/disable the menu icons shown at the lefthand side of the menu entries.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Enable Settings Tab")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Set Password For Enabling Settings Tab")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD,
      "Enter Password")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_OK,
      "Password correct.")
MSG_HASH(MSG_INPUT_ENABLE_SETTINGS_PASSWORD_NOK,
      "Password incorrect.")
MSG_HASH(MENU_ENUM_SUBLABEL_XMB_MAIN_MENU_ENABLE_SETTINGS,
      "Enables the Settings tab. A restart is required for the tab to appear.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_SETTINGS_PASSWORD,
      "Supplying a password when hiding the settings tab makes it possible to later restore it from the menu, by going to the Main Menu tab, selecting Enable Settings Tab and entering the password.")
MSG_HASH(MENU_ENUM_SUBLABEL_PLAYLIST_ENTRY_RENAME,
      "Allow the user to rename entries in collections.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_PLAYLIST_ENTRY_RENAME,
      "Allow to rename entries")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CORE,
      "Show Load Core")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CORE,
      "Show/hide the 'Load Core' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_LOAD_CONTENT,
      "Show Load Content")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_LOAD_CONTENT,
      "Show/hide the 'Load Content' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_INFORMATION,
      "Show Information")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_CONFIGURATIONS,
      "Show Configurations")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_CONFIGURATIONS,
      "Show/hide the 'Configurations' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_HELP,
      "Show Help")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_HELP,
      "Show/hide the 'Help' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_QUIT_RETROARCH,
      "Show Quit RetroArch")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_QUIT_RETROARCH,
      "Show/hide the 'Quit RetroArch' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_SHOW_REBOOT,
      "Show Reboot")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_SHOW_REBOOT,
      "Show/hide the 'Reboot' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_VIEWS_SETTINGS,
      "Quick Menu")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_VIEWS_SETTINGS,
      "Show or hide elements on the Quick Menu screen.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Show Take Screenshot")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_TAKE_SCREENSHOT,
      "Show/hide the 'Take Screenshot' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Show Save/Load State")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_LOAD_STATE,
      "Show/hide the options for saving/loading state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Show Undo Save/Load State")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_UNDO_SAVE_LOAD_STATE,
      "Show/hide the options for undoing save/load state.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show Add to Favorites")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_ADD_TO_FAVORITES,
      "Show/hide the 'Add to Favorites' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_OPTIONS,
      "Show Options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_OPTIONS,
      "Show/hide the 'Options' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CONTROLS,
      "Show Controls")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CONTROLS,
      "Show/hide the 'Controls' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_CHEATS,
      "Show Cheats")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_CHEATS,
      "Show/hide the 'Cheats' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SHADERS,
      "Show Shaders")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SHADERS,
      "Show/hide the 'Shaders' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Show Save Core Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_CORE_OVERRIDES,
      "Show/hide the 'Save Core Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Show Save Game Overrides")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_SAVE_GAME_OVERRIDES,
      "Show/hide the 'Save Game Overrides' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_SHOW_INFORMATION,
      "Show Information")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_SHOW_INFORMATION,
      "Show/hide the 'Information' option.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_DISABLE_KIOSK_MODE,
      "Disable Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_DISABLE_KIOSK_MODE,
      "Disables kiosk mode. A restart is required for the change to take full effect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_ENABLE_KIOSK_MODE,
      "Enable Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_ENABLE_KIOSK_MODE,
      "Protects the setup by hiding all configuration related settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_KIOSK_MODE_PASSWORD,
      "Set Password For Disabling Kiosk Mode")
MSG_HASH(MENU_ENUM_SUBLABEL_MENU_KIOSK_MODE_PASSWORD,
      "Supplying a password when enabling kiosk mode makes it possible to later disable it from the menu, by going to the Main Menu, selecting Disable Kiosk Mode and entering the password.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD,
      "Enter Password")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_OK,
      "Password correct.")
MSG_HASH(MSG_INPUT_KIOSK_MODE_PASSWORD_NOK,
      "Password incorrect.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Automatically add content to playlist")
MSG_HASH(MENU_ENUM_SUBLABEL_AUTOMATICALLY_ADD_CONTENT_TO_PLAYLIST,
      "Automatically scans loaded content so they appear inside playlists.")
MSG_HASH(MSG_SCANNING_OF_FILE_FINISHED,
      "Scanning of file finished")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_RESAMPLER_QUALITY,
      "Audio Resampler Quality")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_RESAMPLER_QUALITY,
      "Lower this value to favor performance/lower latency over audio quality, increase if you want better audio quality at the expense of performance/lower latency.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_STATISTICS_SHOW,
      "Display Statistics")
MSG_HASH(MENU_ENUM_SUBLABEL_STATISTICS_SHOW,
      "Show onscreen technical statistics.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_ENABLE,
      "Enable border filler")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BORDER_FILLER_THICKNESS_ENABLE,
      "Enable border filler thickness")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MENU_RGUI_BACKGROUND_FILLER_THICKNESS_ENABLE,
      "Enable background filler thickness")
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION, "For 15 kHz CRT displays only. Attempts to use exact core/game resolution and refresh rate.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION, "CRT SwitchRes") 
MSG_HASH(MENU_ENUM_SUBLABEL_CRT_SWITCH_RESOLUTION_SUPER, "When CRT SwitchRes is enabled, force ultrawide horizontal resolution to minimize mode switching.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CRT_SWITCH_RESOLUTION_SUPER, "CRT Super Resolution") 
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_REWIND,
      "Show Rewind Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_REWIND,
      "Show/hide the Rewind options.")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_LATENCY,
      "Show/hide the Latency options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_LATENCY,
      "Show Latency Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_CONTENT_SHOW_OVERLAYS,
      "Show/hide the Overlay options.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_CONTENT_SHOW_OVERLAYS,
      "Show Overlay Settings")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_ENABLE_MENU,
      "Enable menu audio")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_ENABLE_MENU,
      "Enable or disable menu sound.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_AUDIO_MIXER_SETTINGS,
      "Mixer Settings")
MSG_HASH(MENU_ENUM_SUBLABEL_AUDIO_MIXER_SETTINGS,
      "View and/or modify audio mixer settings.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_QUICK_MENU_OVERRIDE_OPTIONS,
      "Configuration Override options")
MSG_HASH(MENU_ENUM_SUBLABEL_QUICK_MENU_OVERRIDE_OPTIONS,
      "Options for overriding the global configuration.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY,
      "Will start playback of the audio stream. Once finished, it will remove the current audio stream from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_LOOPED,
      "Will start playback of the audio stream. Once finished, it will loop and play the track again from the beginning.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Will start playback of the audio stream. Once finished, it will jump to the next audio stream in sequential order and repeat this behavior. Useful as an album playback mode.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_STOP,
      "This will stop playback of the audio stream, but not remove it from memory. You can start playing it again by selecting 'Play'.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_REMOVE,
      "This will stop playback of the audio stream and remove it entirely from memory.")
MSG_HASH(MENU_ENUM_SUBLABEL_MIXER_ACTION_VOLUME,
      "Adjust the volume of the audio stream.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER,
      "Add this audio track to an available audio stream slot. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_SUBLABEL_ADD_TO_MIXER_AND_PLAY,
      "Add this audio track to an available audio stream slot and play it. If no slots are currently available, it will be ignored.")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY,
      "Play")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_LOOPED,
      "Play (Looped)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_PLAY_SEQUENTIAL,
      "Play (Sequential)")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_STOP,
      "Stop")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_REMOVE,
      "Remove")
MSG_HASH(MENU_ENUM_LABEL_VALUE_MIXER_ACTION_VOLUME,
      "Volume")
